pub struct CanonicalAction {
pub command: String,
pub kind: String,
pub executable: bool,
pub note: String,
pub argv: Option<Vec<String>>,
pub template: Option<ActionTemplate>,
}Fields
command: Stringkind: Stringexecutable: boolnote: Stringargv: Option<Vec<String>>template: Option<ActionTemplate>Trait Implementations
Sourceimpl Clone for CanonicalAction
impl Clone for CanonicalAction
Sourcefn clone(&self) -> CanonicalAction
fn clone(&self) -> CanonicalAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CanonicalAction
impl Debug for CanonicalAction
Sourceimpl JsonSchema for CanonicalAction
impl JsonSchema for CanonicalAction
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CanonicalAction
impl RefUnwindSafe for CanonicalAction
impl Send for CanonicalAction
impl Sync for CanonicalAction
impl Unpin for CanonicalAction
impl UnsafeUnpin for CanonicalAction
impl UnwindSafe for CanonicalAction