pub struct CommandAction {
pub action: String,
pub executable: bool,
pub argv: Option<Vec<String>>,
pub template: Option<ActionTemplate>,
}Fields
action: Stringexecutable: boolargv: Option<Vec<String>>template: Option<ActionTemplate>Trait Implementations
Sourceimpl Clone for CommandAction
impl Clone for CommandAction
Sourcefn clone(&self) -> CommandAction
fn clone(&self) -> CommandAction
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandAction
impl Debug for CommandAction
Sourceimpl JsonSchema for CommandAction
impl JsonSchema for CommandAction
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommandAction
impl RefUnwindSafe for CommandAction
impl Send for CommandAction
impl Sync for CommandAction
impl Unpin for CommandAction
impl UnsafeUnpin for CommandAction
impl UnwindSafe for CommandAction