pub struct CommandCatalogArgument {
pub id: String,
pub value_names: Vec<String>,
pub help: Option<String>,
pub required: bool,
}Fields
id: Stringvalue_names: Vec<String>help: Option<String>required: boolTrait Implementations
Sourceimpl Clone for CommandCatalogArgument
impl Clone for CommandCatalogArgument
Sourcefn clone(&self) -> CommandCatalogArgument
fn clone(&self) -> CommandCatalogArgument
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandCatalogArgument
impl Debug for CommandCatalogArgument
Sourceimpl JsonSchema for CommandCatalogArgument
impl JsonSchema for CommandCatalogArgument
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommandCatalogArgument
impl RefUnwindSafe for CommandCatalogArgument
impl Send for CommandCatalogArgument
impl Sync for CommandCatalogArgument
impl Unpin for CommandCatalogArgument
impl UnsafeUnpin for CommandCatalogArgument
impl UnwindSafe for CommandCatalogArgument