pub struct CommandCatalogExitCode {
pub code: u8,
pub reason: String,
}Fields
code: u8reason: StringTrait Implementations
Sourceimpl Clone for CommandCatalogExitCode
impl Clone for CommandCatalogExitCode
Sourcefn clone(&self) -> CommandCatalogExitCode
fn clone(&self) -> CommandCatalogExitCode
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandCatalogExitCode
impl Debug for CommandCatalogExitCode
Sourceimpl JsonSchema for CommandCatalogExitCode
impl JsonSchema for CommandCatalogExitCode
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommandCatalogExitCode
impl RefUnwindSafe for CommandCatalogExitCode
impl Send for CommandCatalogExitCode
impl Sync for CommandCatalogExitCode
impl Unpin for CommandCatalogExitCode
impl UnsafeUnpin for CommandCatalogExitCode
impl UnwindSafe for CommandCatalogExitCode