pub struct CommandCatalogOption {
pub id: String,
pub long: Option<String>,
pub aliases: Vec<String>,
pub short: Option<String>,
pub value_names: Vec<String>,
pub value_kind: String,
pub default_values: Vec<String>,
pub possible_values: Vec<String>,
pub help: Option<String>,
pub required: bool,
pub global: bool,
pub hidden: bool,
}Fields
id: Stringlong: Option<String>aliases: Vec<String>short: Option<String>value_names: Vec<String>value_kind: Stringdefault_values: Vec<String>possible_values: Vec<String>help: Option<String>required: boolglobal: boolTrait Implementations
Sourceimpl Clone for CommandCatalogOption
impl Clone for CommandCatalogOption
Sourcefn clone(&self) -> CommandCatalogOption
fn clone(&self) -> CommandCatalogOption
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandCatalogOption
impl Debug for CommandCatalogOption
Sourceimpl JsonSchema for CommandCatalogOption
impl JsonSchema for CommandCatalogOption
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommandCatalogOption
impl RefUnwindSafe for CommandCatalogOption
impl Send for CommandCatalogOption
impl Sync for CommandCatalogOption
impl Unpin for CommandCatalogOption
impl UnsafeUnpin for CommandCatalogOption
impl UnwindSafe for CommandCatalogOption