pub struct CommandJsonDiscriminator {
pub path: Vec<String>,
pub display: String,
pub schema_verb: Option<String>,
pub field: String,
pub value: String,
pub no_schema_reason: Option<String>,
}Fields
path: Vec<String>display: Stringschema_verb: Option<String>field: Stringvalue: Stringno_schema_reason: Option<String>Trait Implementations
Sourceimpl Clone for CommandJsonDiscriminator
impl Clone for CommandJsonDiscriminator
Sourcefn clone(&self) -> CommandJsonDiscriminator
fn clone(&self) -> CommandJsonDiscriminator
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CommandJsonDiscriminator
impl Debug for CommandJsonDiscriminator
impl Eq for CommandJsonDiscriminator
Sourceimpl JsonSchema for CommandJsonDiscriminator
impl JsonSchema for CommandJsonDiscriminator
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CommandJsonDiscriminator
impl PartialEq for CommandJsonDiscriminator
Sourceimpl Serialize for CommandJsonDiscriminator
impl Serialize for CommandJsonDiscriminator
impl StructuralPartialEq for CommandJsonDiscriminator