pub struct ActorChainEntrySchema {
pub session_id: String,
pub native_actor_key: Option<String>,
pub native_parent_actor_key: Option<String>,
pub thread: String,
pub status: String,
pub provider: Option<String>,
pub model: Option<String>,
pub harness: Option<String>,
}Fields
session_id: Stringnative_actor_key: Option<String>native_parent_actor_key: Option<String>thread: Stringstatus: Stringprovider: Option<String>model: Option<String>harness: Option<String>Trait Implementations
Sourceimpl Debug for ActorChainEntrySchema
impl Debug for ActorChainEntrySchema
Sourceimpl JsonSchema for ActorChainEntrySchema
impl JsonSchema for ActorChainEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ActorChainEntrySchema
impl RefUnwindSafe for ActorChainEntrySchema
impl Send for ActorChainEntrySchema
impl Sync for ActorChainEntrySchema
impl Unpin for ActorChainEntrySchema
impl UnsafeUnpin for ActorChainEntrySchema
impl UnwindSafe for ActorChainEntrySchema