pub struct ActorEntrySchema {Show 25 fields
pub session_id: String,
pub client_instance_id: Option<String>,
pub native_actor_key: Option<String>,
pub native_parent_actor_key: Option<String>,
pub native_instance_key: Option<String>,
pub heddle_session_id: Option<String>,
pub thread: String,
pub thread_id: Option<String>,
pub base_state: String,
pub path: Option<String>,
pub provider: Option<String>,
pub model: Option<String>,
pub harness: Option<String>,
pub thinking_level: Option<String>,
pub usage_summary: Value,
pub last_progress_at: Option<String>,
pub report_flush_state: Option<String>,
pub attach_reason: Option<String>,
pub attach_precedence: Vec<String>,
pub winning_attach_rule: Option<String>,
pub probe_source: Option<String>,
pub probe_confidence: Option<f32>,
pub status: String,
pub started_at: String,
pub actor_chain: Vec<ActorChainEntrySchema>,
}Fields
session_id: Stringclient_instance_id: Option<String>native_actor_key: Option<String>native_parent_actor_key: Option<String>native_instance_key: Option<String>heddle_session_id: Option<String>thread: Stringthread_id: Option<String>base_state: Stringpath: Option<String>provider: Option<String>model: Option<String>harness: Option<String>thinking_level: Option<String>usage_summary: Valuelast_progress_at: Option<String>report_flush_state: Option<String>attach_reason: Option<String>attach_precedence: Vec<String>winning_attach_rule: Option<String>probe_source: Option<String>probe_confidence: Option<f32>status: Stringstarted_at: Stringactor_chain: Vec<ActorChainEntrySchema>Trait Implementations
Sourceimpl Debug for ActorEntrySchema
impl Debug for ActorEntrySchema
Sourceimpl JsonSchema for ActorEntrySchema
impl JsonSchema for ActorEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ActorEntrySchema
impl RefUnwindSafe for ActorEntrySchema
impl Send for ActorEntrySchema
impl Sync for ActorEntrySchema
impl Unpin for ActorEntrySchema
impl UnsafeUnpin for ActorEntrySchema
impl UnwindSafe for ActorEntrySchema