pub struct ActorInfoSchema {
pub provider: Option<String>,
pub model: Option<String>,
}Fields
provider: Option<String>model: Option<String>Trait Implementations
Sourceimpl Debug for ActorInfoSchema
impl Debug for ActorInfoSchema
Sourceimpl JsonSchema for ActorInfoSchema
impl JsonSchema for ActorInfoSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ActorInfoSchema
impl RefUnwindSafe for ActorInfoSchema
impl Send for ActorInfoSchema
impl Sync for ActorInfoSchema
impl Unpin for ActorInfoSchema
impl UnsafeUnpin for ActorInfoSchema
impl UnwindSafe for ActorInfoSchema