pub struct AdoptSchema {Show 16 fields
pub output_kind: Option<String>,
pub status: Option<String>,
pub action: Option<String>,
pub adopted: bool,
pub initialized: bool,
pub path: String,
pub refs: Vec<String>,
pub commits_imported: usize,
pub states_created: usize,
pub branches_synced: usize,
pub tags_synced: usize,
pub skipped_non_commit_refs: usize,
pub already_in_sync: bool,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub trust: RepositoryVerificationStateSchema,
}Fields
output_kind: Option<String>status: Option<String>action: Option<String>adopted: boolinitialized: boolpath: Stringrefs: Vec<String>commits_imported: usizestates_created: usizebranches_synced: usizeskipped_non_commit_refs: usizealready_in_sync: boolrecommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>trust: RepositoryVerificationStateSchemaTrait Implementations
Sourceimpl Debug for AdoptSchema
impl Debug for AdoptSchema
Sourceimpl JsonSchema for AdoptSchema
impl JsonSchema for AdoptSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AdoptSchema
impl RefUnwindSafe for AdoptSchema
impl Send for AdoptSchema
impl Sync for AdoptSchema
impl Unpin for AdoptSchema
impl UnsafeUnpin for AdoptSchema
impl UnwindSafe for AdoptSchema