pub struct AgentPresenceExplainSchema {Show 22 fields
pub output_kind: String,
pub attached: Option<bool>,
pub active_presence: Option<Value>,
pub reason: Option<String>,
pub repository: Option<String>,
pub detected: Option<Value>,
pub environment: Option<Value>,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub session_id: Option<String>,
pub thread: Option<String>,
pub heddle_session_id: Option<String>,
pub client_instance_id: Option<String>,
pub native_actor_key: Option<String>,
pub native_parent_actor_key: Option<String>,
pub native_instance_key: Option<String>,
pub probe_source: Option<String>,
pub probe_confidence: Option<f32>,
pub attach_reason: Option<String>,
pub attach_precedence: Option<Vec<String>>,
pub winning_rule: Option<String>,
pub trust: RepositoryVerificationStateSchema,
}Fields
output_kind: Stringattached: Option<bool>active_presence: Option<Value>reason: Option<String>repository: Option<String>detected: Option<Value>environment: Option<Value>recommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>session_id: Option<String>thread: Option<String>heddle_session_id: Option<String>client_instance_id: Option<String>native_actor_key: Option<String>native_parent_actor_key: Option<String>native_instance_key: Option<String>probe_source: Option<String>probe_confidence: Option<f32>attach_reason: Option<String>attach_precedence: Option<Vec<String>>winning_rule: Option<String>trust: RepositoryVerificationStateSchemaTrait Implementations
Sourceimpl Debug for AgentPresenceExplainSchema
impl Debug for AgentPresenceExplainSchema
Sourceimpl JsonSchema for AgentPresenceExplainSchema
impl JsonSchema for AgentPresenceExplainSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentPresenceExplainSchema
impl RefUnwindSafe for AgentPresenceExplainSchema
impl Send for AgentPresenceExplainSchema
impl Sync for AgentPresenceExplainSchema
impl Unpin for AgentPresenceExplainSchema
impl UnsafeUnpin for AgentPresenceExplainSchema
impl UnwindSafe for AgentPresenceExplainSchema