pub struct AgentProvenanceEnvelopeSchema {
pub session: SessionEntrySchema,
}Fields
session: SessionEntrySchemaTrait Implementations
Sourceimpl JsonSchema for AgentProvenanceEnvelopeSchema
impl JsonSchema for AgentProvenanceEnvelopeSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentProvenanceEnvelopeSchema
impl RefUnwindSafe for AgentProvenanceEnvelopeSchema
impl Send for AgentProvenanceEnvelopeSchema
impl Sync for AgentProvenanceEnvelopeSchema
impl Unpin for AgentProvenanceEnvelopeSchema
impl UnsafeUnpin for AgentProvenanceEnvelopeSchema
impl UnwindSafe for AgentProvenanceEnvelopeSchema