pub struct AgentReservationEnvelopeSchema {
pub reservation: AgentReservationSchema,
pub token: Option<String>,
pub trust: RepositoryVerificationStateSchema,
}Fields
reservation: AgentReservationSchematoken: Option<String>trust: RepositoryVerificationStateSchemaTrait Implementations
Sourceimpl JsonSchema for AgentReservationEnvelopeSchema
impl JsonSchema for AgentReservationEnvelopeSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentReservationEnvelopeSchema
impl RefUnwindSafe for AgentReservationEnvelopeSchema
impl Send for AgentReservationEnvelopeSchema
impl Sync for AgentReservationEnvelopeSchema
impl Unpin for AgentReservationEnvelopeSchema
impl UnsafeUnpin for AgentReservationEnvelopeSchema
impl UnwindSafe for AgentReservationEnvelopeSchema