pub struct AgentReservationSchema {
pub lease_id: String,
pub actor_session_id: Option<String>,
pub thread: String,
pub anchor_state: Option<String>,
pub anchor_root: Option<String>,
pub task_assignment_id: Option<String>,
pub status: String,
pub path: Option<String>,
pub heartbeat_at: String,
pub lease_expires_at: String,
pub liveness: String,
}Fields
lease_id: Stringactor_session_id: Option<String>thread: Stringanchor_state: Option<String>anchor_root: Option<String>task_assignment_id: Option<String>status: Stringpath: Option<String>heartbeat_at: Stringlease_expires_at: Stringliveness: StringTrait Implementations
Sourceimpl Debug for AgentReservationSchema
impl Debug for AgentReservationSchema
Sourceimpl JsonSchema for AgentReservationSchema
impl JsonSchema for AgentReservationSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentReservationSchema
impl RefUnwindSafe for AgentReservationSchema
impl Send for AgentReservationSchema
impl Sync for AgentReservationSchema
impl Unpin for AgentReservationSchema
impl UnsafeUnpin for AgentReservationSchema
impl UnwindSafe for AgentReservationSchema