pub struct AgentTaskEnvelopeSchema {
pub output_kind: String,
pub task: AgentTaskSchema,
pub trust: RepositoryVerificationStateSchema,
}Fields
output_kind: Stringtask: AgentTaskSchematrust: RepositoryVerificationStateSchemaTrait Implementations
Sourceimpl Debug for AgentTaskEnvelopeSchema
impl Debug for AgentTaskEnvelopeSchema
Sourceimpl JsonSchema for AgentTaskEnvelopeSchema
impl JsonSchema for AgentTaskEnvelopeSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentTaskEnvelopeSchema
impl RefUnwindSafe for AgentTaskEnvelopeSchema
impl Send for AgentTaskEnvelopeSchema
impl Sync for AgentTaskEnvelopeSchema
impl Unpin for AgentTaskEnvelopeSchema
impl UnsafeUnpin for AgentTaskEnvelopeSchema
impl UnwindSafe for AgentTaskEnvelopeSchema