pub struct AgentTaskListSchema {
pub output_kind: String,
pub tasks: Vec<AgentTaskSchema>,
pub thread: Option<String>,
pub status: Option<String>,
pub trust: RepositoryVerificationStateSchema,
}Fields
output_kind: Stringtasks: Vec<AgentTaskSchema>thread: Option<String>status: Option<String>trust: RepositoryVerificationStateSchemaTrait Implementations
Sourceimpl Debug for AgentTaskListSchema
impl Debug for AgentTaskListSchema
Sourceimpl JsonSchema for AgentTaskListSchema
impl JsonSchema for AgentTaskListSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentTaskListSchema
impl RefUnwindSafe for AgentTaskListSchema
impl Send for AgentTaskListSchema
impl Sync for AgentTaskListSchema
impl Unpin for AgentTaskListSchema
impl UnsafeUnpin for AgentTaskListSchema
impl UnwindSafe for AgentTaskListSchema