pub struct AgentTaskSchema {Show 15 fields
pub schema_version: u32,
pub task_id: String,
pub title: String,
pub body: String,
pub status: String,
pub target_thread: String,
pub base_state: Option<String>,
pub base_root: Option<String>,
pub parent_task_id: Option<String>,
pub coordination_discussion_id: Option<String>,
pub allow_offline: bool,
pub delegated_by: Option<String>,
pub created_at: String,
pub updated_at: String,
pub completed_at: Option<String>,
}Fields
schema_version: u32task_id: Stringtitle: Stringbody: Stringstatus: Stringtarget_thread: Stringbase_state: Option<String>base_root: Option<String>parent_task_id: Option<String>coordination_discussion_id: Option<String>allow_offline: booldelegated_by: Option<String>created_at: Stringupdated_at: Stringcompleted_at: Option<String>Trait Implementations
Sourceimpl Debug for AgentTaskSchema
impl Debug for AgentTaskSchema
Sourceimpl JsonSchema for AgentTaskSchema
impl JsonSchema for AgentTaskSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AgentTaskSchema
impl RefUnwindSafe for AgentTaskSchema
impl Send for AgentTaskSchema
impl Sync for AgentTaskSchema
impl Unpin for AgentTaskSchema
impl UnsafeUnpin for AgentTaskSchema
impl UnwindSafe for AgentTaskSchema