pub struct AuthCreateServiceTokenSchema {
pub output_kind: String,
pub name: String,
pub namespace: String,
pub scope: String,
pub credential_path: String,
pub expires_in_days: u32,
}Fields
output_kind: Stringname: Stringnamespace: Stringscope: Stringcredential_path: StringPath to the .hcred credential file written with mode 0600. The token
and proof key live inside this file and never appear in the contract.
expires_in_days: u32Trait Implementations
Sourceimpl Debug for AuthCreateServiceTokenSchema
impl Debug for AuthCreateServiceTokenSchema
Sourceimpl JsonSchema for AuthCreateServiceTokenSchema
impl JsonSchema for AuthCreateServiceTokenSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AuthCreateServiceTokenSchema
impl RefUnwindSafe for AuthCreateServiceTokenSchema
impl Send for AuthCreateServiceTokenSchema
impl Sync for AuthCreateServiceTokenSchema
impl Unpin for AuthCreateServiceTokenSchema
impl UnsafeUnpin for AuthCreateServiceTokenSchema
impl UnwindSafe for AuthCreateServiceTokenSchema