pub struct AuthStatusSchema {
pub output_kind: String,
pub server: String,
pub authenticated: bool,
pub proof_key_available: bool,
pub subject: Option<String>,
pub credential_id: Option<String>,
pub expires_at: Option<String>,
pub recommended_action: Option<String>,
}Fields
output_kind: Stringserver: Stringauthenticated: boolproof_key_available: boolsubject: Option<String>credential_id: Option<String>expires_at: Option<String>recommended_action: Option<String>Trait Implementations
Sourceimpl Debug for AuthStatusSchema
impl Debug for AuthStatusSchema
Sourceimpl JsonSchema for AuthStatusSchema
impl JsonSchema for AuthStatusSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AuthStatusSchema
impl RefUnwindSafe for AuthStatusSchema
impl Send for AuthStatusSchema
impl Sync for AuthStatusSchema
impl Unpin for AuthStatusSchema
impl UnsafeUnpin for AuthStatusSchema
impl UnwindSafe for AuthStatusSchema