pub struct AvailableGitRefSchema {
pub name: String,
pub git_commit: String,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
}Fields
name: Stringgit_commit: Stringrecommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>Trait Implementations
Sourceimpl Debug for AvailableGitRefSchema
impl Debug for AvailableGitRefSchema
Sourceimpl JsonSchema for AvailableGitRefSchema
impl JsonSchema for AvailableGitRefSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AvailableGitRefSchema
impl RefUnwindSafe for AvailableGitRefSchema
impl Send for AvailableGitRefSchema
impl Sync for AvailableGitRefSchema
impl Unpin for AvailableGitRefSchema
impl UnsafeUnpin for AvailableGitRefSchema
impl UnwindSafe for AvailableGitRefSchema