pub struct CaptureSchema {Show 18 fields
pub output_kind: Option<String>,
pub status: String,
pub action: String,
pub state_id: String,
pub content_hash: String,
pub intent: Option<String>,
pub confidence: Option<f32>,
pub task_assignment_id: Option<String>,
pub principal: CommitPrincipalSchema,
pub agent: Option<CommitAgentSchema>,
pub promotion_suggested: bool,
pub heavy_impact_paths: Vec<String>,
pub signed: bool,
pub message: String,
pub next_action: Option<String>,
pub next_action_template: Option<ActionTemplateSchema>,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
}Fields
output_kind: Option<String>status: Stringaction: Stringstate_id: Stringcontent_hash: Stringintent: Option<String>confidence: Option<f32>task_assignment_id: Option<String>principal: CommitPrincipalSchemaagent: Option<CommitAgentSchema>promotion_suggested: boolheavy_impact_paths: Vec<String>signed: boolmessage: Stringnext_action: Option<String>next_action_template: Option<ActionTemplateSchema>recommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>Trait Implementations
Sourceimpl Debug for CaptureSchema
impl Debug for CaptureSchema
Sourceimpl JsonSchema for CaptureSchema
impl JsonSchema for CaptureSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CaptureSchema
impl RefUnwindSafe for CaptureSchema
impl Send for CaptureSchema
impl Sync for CaptureSchema
impl Unpin for CaptureSchema
impl UnsafeUnpin for CaptureSchema
impl UnwindSafe for CaptureSchema