pub struct ChangeMonitorInspectionSchema {
pub backend: String,
pub status: String,
pub reason: Option<String>,
pub changed_path_count: usize,
}Fields
backend: Stringstatus: Stringreason: Option<String>changed_path_count: usizeTrait Implementations
Sourceimpl JsonSchema for ChangeMonitorInspectionSchema
impl JsonSchema for ChangeMonitorInspectionSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChangeMonitorInspectionSchema
impl RefUnwindSafe for ChangeMonitorInspectionSchema
impl Send for ChangeMonitorInspectionSchema
impl Sync for ChangeMonitorInspectionSchema
impl Unpin for ChangeMonitorInspectionSchema
impl UnsafeUnpin for ChangeMonitorInspectionSchema
impl UnwindSafe for ChangeMonitorInspectionSchema