pub struct CollapsedEntrySchema {
pub expandable: bool,
pub source_count: usize,
}Fields
expandable: boolsource_count: usizeTrait Implementations
Sourceimpl Debug for CollapsedEntrySchema
impl Debug for CollapsedEntrySchema
Sourceimpl JsonSchema for CollapsedEntrySchema
impl JsonSchema for CollapsedEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CollapsedEntrySchema
impl RefUnwindSafe for CollapsedEntrySchema
impl Send for CollapsedEntrySchema
impl Sync for CollapsedEntrySchema
impl Unpin for CollapsedEntrySchema
impl UnsafeUnpin for CollapsedEntrySchema
impl UnwindSafe for CollapsedEntrySchema