pub struct CommandContractSchemaCoverageSchema {Show 39 fields
pub status: String,
pub verified_scope: String,
pub advanced_scope: String,
pub summary: String,
pub catalog_commands_total: usize,
pub catalog_mutating_commands_total: usize,
pub json_commands_total: usize,
pub json_mutating_commands_total: usize,
pub json_commands_with_schema: usize,
pub json_commands_with_accepted_opaque_schema: usize,
pub json_commands_without_schema: usize,
pub verified_scope_json_commands_total: usize,
pub verified_scope_json_commands_with_schema: usize,
pub verified_scope_json_commands_with_accepted_opaque_schema: usize,
pub verified_scope_json_commands_without_schema: usize,
pub advanced_scope_json_commands_total: usize,
pub advanced_scope_json_commands_with_accepted_opaque_schema: usize,
pub mutating_commands_total: usize,
pub mutating_commands_with_schema: usize,
pub mutating_commands_with_accepted_opaque_schema: usize,
pub mutating_commands_without_schema: usize,
pub verified_scope_mutating_commands_total: usize,
pub verified_scope_mutating_commands_with_schema: usize,
pub verified_scope_mutating_commands_with_accepted_opaque_schema: usize,
pub verified_scope_mutating_commands_without_schema: usize,
pub advanced_scope_mutating_commands_total: usize,
pub advanced_scope_mutating_commands_with_accepted_opaque_schema: usize,
pub undocumented_schema_verbs_total: usize,
pub opaque_schema_verbs_total: usize,
pub accepted_opaque_schema_verbs_total: usize,
pub unaccepted_opaque_schema_verbs_total: usize,
pub missing_schema_examples: Vec<String>,
pub missing_mutating_schema_examples: Vec<String>,
pub verified_scope_missing_schema_examples: Vec<String>,
pub verified_scope_accepted_opaque_schema_examples: Vec<String>,
pub advanced_scope_accepted_opaque_schema_examples: Vec<String>,
pub accepted_opaque_schema_examples: Vec<String>,
pub unaccepted_opaque_schema_examples: Vec<String>,
pub undocumented_schema_examples: Vec<String>,
}Fields
status: Stringverified_scope: Stringadvanced_scope: Stringsummary: Stringcatalog_commands_total: usizecatalog_mutating_commands_total: usizejson_commands_total: usizejson_mutating_commands_total: usizejson_commands_with_schema: usizejson_commands_with_accepted_opaque_schema: usizejson_commands_without_schema: usizeverified_scope_json_commands_total: usizeverified_scope_json_commands_with_schema: usizeverified_scope_json_commands_with_accepted_opaque_schema: usizeverified_scope_json_commands_without_schema: usizeadvanced_scope_json_commands_total: usizeadvanced_scope_json_commands_with_accepted_opaque_schema: usizemutating_commands_total: usizemutating_commands_with_schema: usizemutating_commands_with_accepted_opaque_schema: usizemutating_commands_without_schema: usizeverified_scope_mutating_commands_total: usizeverified_scope_mutating_commands_with_schema: usizeverified_scope_mutating_commands_with_accepted_opaque_schema: usizeverified_scope_mutating_commands_without_schema: usizeadvanced_scope_mutating_commands_total: usizeadvanced_scope_mutating_commands_with_accepted_opaque_schema: usizeundocumented_schema_verbs_total: usizeopaque_schema_verbs_total: usizeaccepted_opaque_schema_verbs_total: usizeunaccepted_opaque_schema_verbs_total: usizemissing_schema_examples: Vec<String>missing_mutating_schema_examples: Vec<String>verified_scope_missing_schema_examples: Vec<String>verified_scope_accepted_opaque_schema_examples: Vec<String>advanced_scope_accepted_opaque_schema_examples: Vec<String>accepted_opaque_schema_examples: Vec<String>unaccepted_opaque_schema_examples: Vec<String>undocumented_schema_examples: Vec<String>Trait Implementations
Sourceimpl JsonSchema for CommandContractSchemaCoverageSchema
impl JsonSchema for CommandContractSchemaCoverageSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommandContractSchemaCoverageSchema
impl RefUnwindSafe for CommandContractSchemaCoverageSchema
impl Send for CommandContractSchemaCoverageSchema
impl Sync for CommandContractSchemaCoverageSchema
impl Unpin for CommandContractSchemaCoverageSchema
impl UnsafeUnpin for CommandContractSchemaCoverageSchema
impl UnwindSafe for CommandContractSchemaCoverageSchema