pub struct CommitGraphInspectionSchema {
pub present: bool,
pub node_count: usize,
pub bloom_covered_nodes: usize,
pub bytes: u64,
pub error: Option<String>,
}Fields
present: boolnode_count: usizebloom_covered_nodes: usizebytes: u64error: Option<String>Trait Implementations
Sourceimpl Debug for CommitGraphInspectionSchema
impl Debug for CommitGraphInspectionSchema
Sourceimpl JsonSchema for CommitGraphInspectionSchema
impl JsonSchema for CommitGraphInspectionSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommitGraphInspectionSchema
impl RefUnwindSafe for CommitGraphInspectionSchema
impl Send for CommitGraphInspectionSchema
impl Sync for CommitGraphInspectionSchema
impl Unpin for CommitGraphInspectionSchema
impl UnsafeUnpin for CommitGraphInspectionSchema
impl UnwindSafe for CommitGraphInspectionSchema