pub struct CommitPrincipalSchema {
pub name: String,
pub email: String,
}Fields
name: Stringemail: StringTrait Implementations
Sourceimpl Debug for CommitPrincipalSchema
impl Debug for CommitPrincipalSchema
Sourceimpl JsonSchema for CommitPrincipalSchema
impl JsonSchema for CommitPrincipalSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommitPrincipalSchema
impl RefUnwindSafe for CommitPrincipalSchema
impl Send for CommitPrincipalSchema
impl Sync for CommitPrincipalSchema
impl Unpin for CommitPrincipalSchema
impl UnsafeUnpin for CommitPrincipalSchema
impl UnwindSafe for CommitPrincipalSchema