pub struct CommitSchema {
pub output_kind: String,
pub action: String,
pub status: String,
pub state_id: String,
pub git_commit: String,
pub summary: String,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub verification: RepositoryVerificationStateSchema,
}Fields
output_kind: Stringaction: Stringstatus: Stringstate_id: Stringgit_commit: Stringsummary: Stringrecommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>verification: RepositoryVerificationStateSchemaTrait Implementations
Sourceimpl Debug for CommitSchema
impl Debug for CommitSchema
Sourceimpl JsonSchema for CommitSchema
impl JsonSchema for CommitSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for CommitSchema
impl RefUnwindSafe for CommitSchema
impl Send for CommitSchema
impl Sync for CommitSchema
impl Unpin for CommitSchema
impl UnsafeUnpin for CommitSchema
impl UnwindSafe for CommitSchema