pub struct DiscussionListSchema {
pub output_kind: String,
pub discussions: Vec<DiscussionSchema>,
}Fields
output_kind: Stringdiscussions: Vec<DiscussionSchema>Trait Implementations
Sourceimpl Debug for DiscussionListSchema
impl Debug for DiscussionListSchema
Sourceimpl JsonSchema for DiscussionListSchema
impl JsonSchema for DiscussionListSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscussionListSchema
impl RefUnwindSafe for DiscussionListSchema
impl Send for DiscussionListSchema
impl Sync for DiscussionListSchema
impl Unpin for DiscussionListSchema
impl UnsafeUnpin for DiscussionListSchema
impl UnwindSafe for DiscussionListSchema