pub struct DiscussionResolutionSchema {
pub kind: String,
pub annotation_id: Option<String>,
pub state_id: Option<String>,
pub change_id: Option<String>,
pub reason: Option<String>,
}Fields
kind: Stringannotation_id: Option<String>state_id: Option<String>change_id: Option<String>reason: Option<String>Trait Implementations
Sourceimpl Debug for DiscussionResolutionSchema
impl Debug for DiscussionResolutionSchema
Sourceimpl JsonSchema for DiscussionResolutionSchema
impl JsonSchema for DiscussionResolutionSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscussionResolutionSchema
impl RefUnwindSafe for DiscussionResolutionSchema
impl Send for DiscussionResolutionSchema
impl Sync for DiscussionResolutionSchema
impl Unpin for DiscussionResolutionSchema
impl UnsafeUnpin for DiscussionResolutionSchema
impl UnwindSafe for DiscussionResolutionSchema