pub struct DiscussionSchema {
pub id: String,
pub title: String,
pub anchor: DiscussionAnchorSchema,
pub visibility: String,
pub status: String,
pub resolution: Option<DiscussionResolutionSchema>,
pub conflict_operation_ids: Vec<String>,
pub head_operation_ids: Vec<String>,
pub display_head_operation_id: String,
pub turns: Vec<DiscussionTurnSchema>,
}Fields
id: Stringtitle: Stringanchor: DiscussionAnchorSchemavisibility: Stringstatus: Stringresolution: Option<DiscussionResolutionSchema>conflict_operation_ids: Vec<String>head_operation_ids: Vec<String>display_head_operation_id: Stringturns: Vec<DiscussionTurnSchema>Trait Implementations
Sourceimpl Debug for DiscussionSchema
impl Debug for DiscussionSchema
Sourceimpl JsonSchema for DiscussionSchema
impl JsonSchema for DiscussionSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscussionSchema
impl RefUnwindSafe for DiscussionSchema
impl Send for DiscussionSchema
impl Sync for DiscussionSchema
impl Unpin for DiscussionSchema
impl UnsafeUnpin for DiscussionSchema
impl UnwindSafe for DiscussionSchema