pub struct DiscussionShowSchema {
pub output_kind: String,
pub discussion: DiscussionSchema,
}Fields
output_kind: Stringdiscussion: DiscussionSchemaTrait Implementations
Sourceimpl Debug for DiscussionShowSchema
impl Debug for DiscussionShowSchema
Sourceimpl JsonSchema for DiscussionShowSchema
impl JsonSchema for DiscussionShowSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscussionShowSchema
impl RefUnwindSafe for DiscussionShowSchema
impl Send for DiscussionShowSchema
impl Sync for DiscussionShowSchema
impl Unpin for DiscussionShowSchema
impl UnsafeUnpin for DiscussionShowSchema
impl UnwindSafe for DiscussionShowSchema