pub struct DiscussionTurnSchema {
pub operation_id: String,
pub author_name: String,
pub author_email: String,
pub agent: Option<String>,
pub occurred_at_ms: i64,
pub body: String,
pub content_hash: String,
}Fields
operation_id: Stringagent: Option<String>occurred_at_ms: i64body: Stringcontent_hash: StringTrait Implementations
Sourceimpl Debug for DiscussionTurnSchema
impl Debug for DiscussionTurnSchema
Sourceimpl JsonSchema for DiscussionTurnSchema
impl JsonSchema for DiscussionTurnSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscussionTurnSchema
impl RefUnwindSafe for DiscussionTurnSchema
impl Send for DiscussionTurnSchema
impl Sync for DiscussionTurnSchema
impl Unpin for DiscussionTurnSchema
impl UnsafeUnpin for DiscussionTurnSchema
impl UnwindSafe for DiscussionTurnSchema