pub struct DiscussionWriteSchema {
pub output_kind: String,
pub operation_id: String,
pub disposition: String,
pub discussion: DiscussionSchema,
}Fields
output_kind: Stringoperation_id: Stringdisposition: Stringdiscussion: DiscussionSchemaTrait Implementations
Sourceimpl Debug for DiscussionWriteSchema
impl Debug for DiscussionWriteSchema
Sourceimpl JsonSchema for DiscussionWriteSchema
impl JsonSchema for DiscussionWriteSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DiscussionWriteSchema
impl RefUnwindSafe for DiscussionWriteSchema
impl Send for DiscussionWriteSchema
impl Sync for DiscussionWriteSchema
impl Unpin for DiscussionWriteSchema
impl UnsafeUnpin for DiscussionWriteSchema
impl UnwindSafe for DiscussionWriteSchema