pub struct DoctorDocsIssueSchema {
pub file: String,
pub line: usize,
pub invocation: String,
pub kind: String,
pub detail: String,
pub suggestion: Option<String>,
}Fields
file: Stringline: usizeinvocation: Stringkind: Stringdetail: Stringsuggestion: Option<String>Trait Implementations
Sourceimpl Debug for DoctorDocsIssueSchema
impl Debug for DoctorDocsIssueSchema
Sourceimpl JsonSchema for DoctorDocsIssueSchema
impl JsonSchema for DoctorDocsIssueSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DoctorDocsIssueSchema
impl RefUnwindSafe for DoctorDocsIssueSchema
impl Send for DoctorDocsIssueSchema
impl Sync for DoctorDocsIssueSchema
impl Unpin for DoctorDocsIssueSchema
impl UnsafeUnpin for DoctorDocsIssueSchema
impl UnwindSafe for DoctorDocsIssueSchema