pub struct DoctorDocsSchema {
pub output_kind: String,
pub status: String,
pub verified: bool,
pub recommended_action: Option<String>,
pub files_scanned: usize,
pub issues: Vec<DoctorDocsIssueSchema>,
}Fields
output_kind: Stringstatus: Stringverified: boolrecommended_action: Option<String>files_scanned: usizeissues: Vec<DoctorDocsIssueSchema>Trait Implementations
Sourceimpl Debug for DoctorDocsSchema
impl Debug for DoctorDocsSchema
Sourceimpl JsonSchema for DoctorDocsSchema
impl JsonSchema for DoctorDocsSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DoctorDocsSchema
impl RefUnwindSafe for DoctorDocsSchema
impl Send for DoctorDocsSchema
impl Sync for DoctorDocsSchema
impl Unpin for DoctorDocsSchema
impl UnsafeUnpin for DoctorDocsSchema
impl UnwindSafe for DoctorDocsSchema