pub struct DoctorSchema {Show 17 fields
pub output_kind: String,
pub repository: String,
pub repository_capability: String,
pub storage_model: String,
pub hosted_enabled: bool,
pub trust: RepositoryVerificationStateSchema,
pub operation: Option<Value>,
pub remote_tracking: Option<Value>,
pub thread: Option<Value>,
pub state: Option<Value>,
pub changes: Value,
pub workspace: Value,
pub health: Value,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub recovery_commands: Vec<String>,
pub profile: Option<Value>,
}Fields
output_kind: Stringrepository: Stringrepository_capability: Stringstorage_model: Stringhosted_enabled: booltrust: RepositoryVerificationStateSchemaoperation: Option<Value>remote_tracking: Option<Value>thread: Option<Value>state: Option<Value>changes: Valueworkspace: Valuehealth: Valuerecommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>recovery_commands: Vec<String>profile: Option<Value>Trait Implementations
Sourceimpl Debug for DoctorSchema
impl Debug for DoctorSchema
Sourceimpl JsonSchema for DoctorSchema
impl JsonSchema for DoctorSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DoctorSchema
impl RefUnwindSafe for DoctorSchema
impl Send for DoctorSchema
impl Sync for DoctorSchema
impl Unpin for DoctorSchema
impl UnsafeUnpin for DoctorSchema
impl UnwindSafe for DoctorSchema