pub struct DoctorSchemaIssueSchema {
pub verb: String,
pub line: usize,
pub unknown_key: String,
pub detail: String,
}Fields
verb: Stringline: usizeunknown_key: Stringdetail: StringTrait Implementations
Sourceimpl Debug for DoctorSchemaIssueSchema
impl Debug for DoctorSchemaIssueSchema
Sourceimpl JsonSchema for DoctorSchemaIssueSchema
impl JsonSchema for DoctorSchemaIssueSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for DoctorSchemaIssueSchema
impl RefUnwindSafe for DoctorSchemaIssueSchema
impl Send for DoctorSchemaIssueSchema
impl Sync for DoctorSchemaIssueSchema
impl Unpin for DoctorSchemaIssueSchema
impl UnsafeUnpin for DoctorSchemaIssueSchema
impl UnwindSafe for DoctorSchemaIssueSchema