pub struct ErrorEnvelopeSchema {Show 14 fields
pub error: String,
pub exit_code: u8,
pub hint: String,
pub kind: String,
pub op_id: Option<String>,
pub idempotency_status: Option<String>,
pub replayed: Option<bool>,
pub unsafe_condition: String,
pub would_change: String,
pub preserved: String,
pub primary_command: String,
pub primary_command_template: NullableActionTemplateSchema,
pub recovery_commands: Vec<String>,
pub recovery_action_templates: Vec<ActionTemplateSchema>,
}Fields
error: Stringexit_code: u8hint: Stringkind: Stringop_id: Option<String>idempotency_status: Option<String>replayed: Option<bool>unsafe_condition: Stringwould_change: Stringpreserved: Stringprimary_command: Stringprimary_command_template: NullableActionTemplateSchemarecovery_commands: Vec<String>recovery_action_templates: Vec<ActionTemplateSchema>Trait Implementations
Sourceimpl Debug for ErrorEnvelopeSchema
impl Debug for ErrorEnvelopeSchema
Sourceimpl JsonSchema for ErrorEnvelopeSchema
impl JsonSchema for ErrorEnvelopeSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ErrorEnvelopeSchema
impl RefUnwindSafe for ErrorEnvelopeSchema
impl Send for ErrorEnvelopeSchema
impl Sync for ErrorEnvelopeSchema
impl Unpin for ErrorEnvelopeSchema
impl UnsafeUnpin for ErrorEnvelopeSchema
impl UnwindSafe for ErrorEnvelopeSchema