pub struct ExpandSchema {
pub output_kind: String,
pub status: String,
pub requested: String,
pub collapsed: ExpandedCollapseSchema,
pub captures: Vec<ExpandedCaptureSchema>,
}Fields
output_kind: Stringstatus: Stringrequested: Stringcollapsed: ExpandedCollapseSchemacaptures: Vec<ExpandedCaptureSchema>Trait Implementations
Sourceimpl Debug for ExpandSchema
impl Debug for ExpandSchema
Sourceimpl JsonSchema for ExpandSchema
impl JsonSchema for ExpandSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExpandSchema
impl RefUnwindSafe for ExpandSchema
impl Send for ExpandSchema
impl Sync for ExpandSchema
impl Unpin for ExpandSchema
impl UnsafeUnpin for ExpandSchema
impl UnwindSafe for ExpandSchema