pub struct ExpandedCaptureSchema {
pub state_id: String,
pub state_id_full: String,
pub content_hash: String,
pub intent: Option<String>,
pub principal: String,
pub agent: Option<String>,
pub confidence: Option<f32>,
pub created_at: String,
pub parents: Vec<String>,
}Fields
state_id: Stringstate_id_full: Stringcontent_hash: Stringintent: Option<String>principal: Stringagent: Option<String>confidence: Option<f32>created_at: Stringparents: Vec<String>Trait Implementations
Sourceimpl Debug for ExpandedCaptureSchema
impl Debug for ExpandedCaptureSchema
Sourceimpl JsonSchema for ExpandedCaptureSchema
impl JsonSchema for ExpandedCaptureSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExpandedCaptureSchema
impl RefUnwindSafe for ExpandedCaptureSchema
impl Send for ExpandedCaptureSchema
impl Sync for ExpandedCaptureSchema
impl Unpin for ExpandedCaptureSchema
impl UnsafeUnpin for ExpandedCaptureSchema
impl UnwindSafe for ExpandedCaptureSchema