pub struct ExportGitSchema {
pub output_kind: Option<String>,
pub states_exported: u64,
pub commits_total: u64,
pub threads_synced: u64,
pub markers_synced: u64,
pub branches: Vec<ExportedRefSchema>,
pub tags: Vec<ExportedRefSchema>,
pub destination: String,
}Fields
output_kind: Option<String>states_exported: u64commits_total: u64threads_synced: u64markers_synced: u64branches: Vec<ExportedRefSchema>destination: StringTrait Implementations
Sourceimpl Debug for ExportGitSchema
impl Debug for ExportGitSchema
Sourceimpl JsonSchema for ExportGitSchema
impl JsonSchema for ExportGitSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExportGitSchema
impl RefUnwindSafe for ExportGitSchema
impl Send for ExportGitSchema
impl Sync for ExportGitSchema
impl Unpin for ExportGitSchema
impl UnsafeUnpin for ExportGitSchema
impl UnwindSafe for ExportGitSchema