pub struct ExportedRefSchema {
pub name: String,
pub tip: String,
}Fields
name: Stringtip: StringTrait Implementations
Sourceimpl Debug for ExportedRefSchema
impl Debug for ExportedRefSchema
Sourceimpl JsonSchema for ExportedRefSchema
impl JsonSchema for ExportedRefSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ExportedRefSchema
impl RefUnwindSafe for ExportedRefSchema
impl Send for ExportedRefSchema
impl Sync for ExportedRefSchema
impl Unpin for ExportedRefSchema
impl UnsafeUnpin for ExportedRefSchema
impl UnwindSafe for ExportedRefSchema