pub struct FsKitReadinessSchema {
pub state: String,
pub backend: String,
pub action: String,
pub settings_url: Option<String>,
}Fields
state: Stringbackend: Stringaction: Stringsettings_url: Option<String>Trait Implementations
Sourceimpl Debug for FsKitReadinessSchema
impl Debug for FsKitReadinessSchema
Sourceimpl JsonSchema for FsKitReadinessSchema
impl JsonSchema for FsKitReadinessSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for FsKitReadinessSchema
impl RefUnwindSafe for FsKitReadinessSchema
impl Send for FsKitReadinessSchema
impl Sync for FsKitReadinessSchema
impl Unpin for FsKitReadinessSchema
impl UnsafeUnpin for FsKitReadinessSchema
impl UnwindSafe for FsKitReadinessSchema