pub struct GenericJsonObjectSchema {
pub fields: BTreeMap<String, Value>,
}Fields
fields: BTreeMap<String, Value>Trait Implementations
Sourceimpl Debug for GenericJsonObjectSchema
impl Debug for GenericJsonObjectSchema
Sourceimpl JsonSchema for GenericJsonObjectSchema
impl JsonSchema for GenericJsonObjectSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GenericJsonObjectSchema
impl RefUnwindSafe for GenericJsonObjectSchema
impl Send for GenericJsonObjectSchema
impl Sync for GenericJsonObjectSchema
impl Unpin for GenericJsonObjectSchema
impl UnsafeUnpin for GenericJsonObjectSchema
impl UnwindSafe for GenericJsonObjectSchema