pub struct GitRemoteConfiguredSchema {
pub name: String,
pub url: String,
}Fields
name: Stringurl: StringTrait Implementations
Sourceimpl Debug for GitRemoteConfiguredSchema
impl Debug for GitRemoteConfiguredSchema
Sourceimpl JsonSchema for GitRemoteConfiguredSchema
impl JsonSchema for GitRemoteConfiguredSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GitRemoteConfiguredSchema
impl RefUnwindSafe for GitRemoteConfiguredSchema
impl Send for GitRemoteConfiguredSchema
impl Sync for GitRemoteConfiguredSchema
impl Unpin for GitRemoteConfiguredSchema
impl UnsafeUnpin for GitRemoteConfiguredSchema
impl UnwindSafe for GitRemoteConfiguredSchema