pub struct GitUpstreamConfiguredSchema {
pub branch: String,
pub remote: String,
}Fields
branch: Stringremote: StringTrait Implementations
Sourceimpl Debug for GitUpstreamConfiguredSchema
impl Debug for GitUpstreamConfiguredSchema
Sourceimpl JsonSchema for GitUpstreamConfiguredSchema
impl JsonSchema for GitUpstreamConfiguredSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for GitUpstreamConfiguredSchema
impl RefUnwindSafe for GitUpstreamConfiguredSchema
impl Send for GitUpstreamConfiguredSchema
impl Sync for GitUpstreamConfiguredSchema
impl Unpin for GitUpstreamConfiguredSchema
impl UnsafeUnpin for GitUpstreamConfiguredSchema
impl UnwindSafe for GitUpstreamConfiguredSchema