pub struct ImportGitSchema {Show 14 fields
pub output_kind: Option<String>,
pub status: String,
pub action: Option<String>,
pub summary: String,
pub commits_imported: u64,
pub states_created: u64,
pub branches_synced: u64,
pub tags_synced: u64,
pub skipped_non_commit_refs: u64,
pub lossy_entries: Vec<LossyImportEntrySchema>,
pub already_in_sync: bool,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub recovery_commands: Vec<String>,
}Fields
output_kind: Option<String>status: Stringaction: Option<String>summary: Stringcommits_imported: u64states_created: u64branches_synced: u64skipped_non_commit_refs: u64lossy_entries: Vec<LossyImportEntrySchema>already_in_sync: boolrecommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>recovery_commands: Vec<String>Trait Implementations
Sourceimpl Debug for ImportGitSchema
impl Debug for ImportGitSchema
Sourceimpl JsonSchema for ImportGitSchema
impl JsonSchema for ImportGitSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ImportGitSchema
impl RefUnwindSafe for ImportGitSchema
impl Send for ImportGitSchema
impl Sync for ImportGitSchema
impl Unpin for ImportGitSchema
impl UnsafeUnpin for ImportGitSchema
impl UnwindSafe for ImportGitSchema