pub struct InitPrincipalSchema {
pub name: String,
pub email: String,
}Fields
name: Stringemail: StringTrait Implementations
Sourceimpl Debug for InitPrincipalSchema
impl Debug for InitPrincipalSchema
Sourceimpl JsonSchema for InitPrincipalSchema
impl JsonSchema for InitPrincipalSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InitPrincipalSchema
impl RefUnwindSafe for InitPrincipalSchema
impl Send for InitPrincipalSchema
impl Sync for InitPrincipalSchema
impl Unpin for InitPrincipalSchema
impl UnsafeUnpin for InitPrincipalSchema
impl UnwindSafe for InitPrincipalSchema