pub struct InitSchema {Show 17 fields
pub output_kind: String,
pub status: String,
pub action: String,
pub path: String,
pub repository_mode: String,
pub git_detected: bool,
pub heddle_initialized: bool,
pub installed_heddleignore: bool,
pub principal_configured: bool,
pub principal_status: String,
pub principal_source: Option<String>,
pub principal: Option<InitPrincipalSchema>,
pub principal_recommended_action: Option<String>,
pub side_effects: Vec<String>,
pub message: String,
pub next_action: Option<String>,
pub recommended_action: Option<String>,
}Fields
output_kind: Stringstatus: Stringaction: Stringpath: Stringrepository_mode: Stringgit_detected: boolheddle_initialized: boolinstalled_heddleignore: boolprincipal_configured: boolprincipal_status: Stringprincipal_source: Option<String>principal: Option<InitPrincipalSchema>principal_recommended_action: Option<String>side_effects: Vec<String>message: Stringnext_action: Option<String>recommended_action: Option<String>Trait Implementations
Sourceimpl Debug for InitSchema
impl Debug for InitSchema
Sourceimpl JsonSchema for InitSchema
impl JsonSchema for InitSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for InitSchema
impl RefUnwindSafe for InitSchema
impl Send for InitSchema
impl Sync for InitSchema
impl Unpin for InitSchema
impl UnsafeUnpin for InitSchema
impl UnwindSafe for InitSchema