pub struct IntegrationStatusListSchema(pub Vec<IntegrationStatusSchema>);Tuple Fields
0: Vec<IntegrationStatusSchema>Trait Implementations
Sourceimpl Debug for IntegrationStatusListSchema
impl Debug for IntegrationStatusListSchema
Sourceimpl JsonSchema for IntegrationStatusListSchema
impl JsonSchema for IntegrationStatusListSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for IntegrationStatusListSchema
impl RefUnwindSafe for IntegrationStatusListSchema
impl Send for IntegrationStatusListSchema
impl Sync for IntegrationStatusListSchema
impl Unpin for IntegrationStatusListSchema
impl UnsafeUnpin for IntegrationStatusListSchema
impl UnwindSafe for IntegrationStatusListSchema