pub struct IntegrationStatusSchema {
pub harness: String,
pub scope: String,
pub method: String,
pub status: String,
pub healthy: bool,
pub paths: Vec<String>,
pub capabilities: Vec<String>,
pub capability_paths: Vec<String>,
pub path_mode: String,
}Fields
harness: Stringscope: Stringmethod: Stringstatus: Stringhealthy: boolpaths: Vec<String>capabilities: Vec<String>capability_paths: Vec<String>path_mode: StringTrait Implementations
Sourceimpl Debug for IntegrationStatusSchema
impl Debug for IntegrationStatusSchema
Sourceimpl JsonSchema for IntegrationStatusSchema
impl JsonSchema for IntegrationStatusSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for IntegrationStatusSchema
impl RefUnwindSafe for IntegrationStatusSchema
impl Send for IntegrationStatusSchema
impl Sync for IntegrationStatusSchema
impl Unpin for IntegrationStatusSchema
impl UnsafeUnpin for IntegrationStatusSchema
impl UnwindSafe for IntegrationStatusSchema