pub struct LogReflogSchema {
pub output_kind: Option<String>,
pub status: Option<String>,
pub repository_capability: String,
pub storage_model: String,
pub entries: Vec<ReflogEntrySchema>,
}Fields
output_kind: Option<String>status: Option<String>repository_capability: Stringstorage_model: Stringentries: Vec<ReflogEntrySchema>Trait Implementations
Sourceimpl Debug for LogReflogSchema
impl Debug for LogReflogSchema
Sourceimpl JsonSchema for LogReflogSchema
impl JsonSchema for LogReflogSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LogReflogSchema
impl RefUnwindSafe for LogReflogSchema
impl Send for LogReflogSchema
impl Sync for LogReflogSchema
impl Unpin for LogReflogSchema
impl UnsafeUnpin for LogReflogSchema
impl UnwindSafe for LogReflogSchema