pub struct LogSchema {
pub output_kind: Option<String>,
pub status: Option<String>,
pub repository_capability: String,
pub storage_model: String,
pub states: Vec<StateEntrySchema>,
}Fields
output_kind: Option<String>status: Option<String>repository_capability: Stringstorage_model: Stringstates: Vec<StateEntrySchema>Trait Implementations
Sourceimpl JsonSchema for LogSchema
impl JsonSchema for LogSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LogSchema
impl RefUnwindSafe for LogSchema
impl Send for LogSchema
impl Sync for LogSchema
impl Unpin for LogSchema
impl UnsafeUnpin for LogSchema
impl UnwindSafe for LogSchema