pub struct MaintenanceInspectReportSchema {
pub commit_graph: CommitGraphInspectionSchema,
pub worktree_index: WorktreeIndexInspectionSchema,
pub change_monitor: ChangeMonitorInspectionSchema,
pub refs: RefCountsInspectionSchema,
pub ref_summary_index: RefSummaryIndexInspectionSchema,
pub pack_files: PackFilesInspectionSchema,
pub partial_fetch: PartialFetchInspectionSchema,
pub pull_planner_cache: PullPlannerCacheInspectionSchema,
}Fields
commit_graph: CommitGraphInspectionSchemaworktree_index: WorktreeIndexInspectionSchemachange_monitor: ChangeMonitorInspectionSchemarefs: RefCountsInspectionSchemaref_summary_index: RefSummaryIndexInspectionSchemapack_files: PackFilesInspectionSchemapartial_fetch: PartialFetchInspectionSchemapull_planner_cache: PullPlannerCacheInspectionSchemaTrait Implementations
Sourceimpl JsonSchema for MaintenanceInspectReportSchema
impl JsonSchema for MaintenanceInspectReportSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MaintenanceInspectReportSchema
impl RefUnwindSafe for MaintenanceInspectReportSchema
impl Send for MaintenanceInspectReportSchema
impl Sync for MaintenanceInspectReportSchema
impl Unpin for MaintenanceInspectReportSchema
impl UnsafeUnpin for MaintenanceInspectReportSchema
impl UnwindSafe for MaintenanceInspectReportSchema