pub struct MaintenanceInspectSchema {
pub output_kind: String,
pub commit_graph: CommitGraphInspectionSchema,
pub worktree_index: WorktreeIndexInspectionSchema,
pub change_monitor: ChangeMonitorInspectionSchema,
pub refs: RefCountsInspectionSchema,
pub ref_summary_index: RefSummaryIndexInspectionSchema,
pub pack_files: PackFilesInspectionSchema,
pub partial_fetch: PartialFetchInspectionSchema,
pub pull_planner_cache: PullPlannerCacheInspectionSchema,
}Fields
output_kind: Stringcommit_graph: CommitGraphInspectionSchemaworktree_index: WorktreeIndexInspectionSchemachange_monitor: ChangeMonitorInspectionSchemarefs: RefCountsInspectionSchemaref_summary_index: RefSummaryIndexInspectionSchemapack_files: PackFilesInspectionSchemapartial_fetch: PartialFetchInspectionSchemapull_planner_cache: PullPlannerCacheInspectionSchemaTrait Implementations
Sourceimpl Debug for MaintenanceInspectSchema
impl Debug for MaintenanceInspectSchema
Sourceimpl JsonSchema for MaintenanceInspectSchema
impl JsonSchema for MaintenanceInspectSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MaintenanceInspectSchema
impl RefUnwindSafe for MaintenanceInspectSchema
impl Send for MaintenanceInspectSchema
impl Sync for MaintenanceInspectSchema
impl Unpin for MaintenanceInspectSchema
impl UnsafeUnpin for MaintenanceInspectSchema
impl UnwindSafe for MaintenanceInspectSchema