pub struct MaintenanceRefreshSchema {Show 15 fields
pub output_kind: String,
pub rebuilt_commit_graph: bool,
pub rebuilt_ref_summary_index: bool,
pub rebuilt_worktree_index: bool,
pub refreshed_change_monitor: bool,
pub rebuilt_pull_planner_cache: bool,
pub pruned_pull_planner_entries: usize,
pub pack_install_intents_recovered_completed: u64,
pub pack_install_intents_aborted: u64,
pub pack_install_intents_skipped_in_progress: u64,
pub pack_install_intents_quarantined: u64,
pub pack_install_metrics: PackInstallMetricsSchema,
pub unpaired_packs_pruned: u64,
pub unpaired_pack_bytes_freed: u64,
pub report: MaintenanceInspectReportSchema,
}Fields
output_kind: Stringrebuilt_commit_graph: boolrebuilt_ref_summary_index: boolrebuilt_worktree_index: boolrefreshed_change_monitor: boolrebuilt_pull_planner_cache: boolpruned_pull_planner_entries: usizepack_install_intents_recovered_completed: u64pack_install_intents_aborted: u64pack_install_intents_skipped_in_progress: u64pack_install_intents_quarantined: u64pack_install_metrics: PackInstallMetricsSchemaunpaired_packs_pruned: u64unpaired_pack_bytes_freed: u64report: MaintenanceInspectReportSchemaTrait Implementations
Sourceimpl Debug for MaintenanceRefreshSchema
impl Debug for MaintenanceRefreshSchema
Sourceimpl JsonSchema for MaintenanceRefreshSchema
impl JsonSchema for MaintenanceRefreshSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MaintenanceRefreshSchema
impl RefUnwindSafe for MaintenanceRefreshSchema
impl Send for MaintenanceRefreshSchema
impl Sync for MaintenanceRefreshSchema
impl Unpin for MaintenanceRefreshSchema
impl UnsafeUnpin for MaintenanceRefreshSchema
impl UnwindSafe for MaintenanceRefreshSchema