pub struct OperatorCommandSchema {
pub output_kind: Option<String>,
pub status: String,
pub action: String,
pub message: String,
pub blockers: Vec<String>,
pub warnings: Vec<String>,
pub next_action: Option<String>,
pub next_action_template: Option<ActionTemplateSchema>,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
}Fields
output_kind: Option<String>status: Stringaction: Stringmessage: Stringblockers: Vec<String>warnings: Vec<String>next_action: Option<String>next_action_template: Option<ActionTemplateSchema>recommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>Trait Implementations
Sourceimpl Debug for OperatorCommandSchema
impl Debug for OperatorCommandSchema
Sourceimpl JsonSchema for OperatorCommandSchema
impl JsonSchema for OperatorCommandSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for OperatorCommandSchema
impl RefUnwindSafe for OperatorCommandSchema
impl Send for OperatorCommandSchema
impl Sync for OperatorCommandSchema
impl Unpin for OperatorCommandSchema
impl UnsafeUnpin for OperatorCommandSchema
impl UnwindSafe for OperatorCommandSchema