pub struct PackFilesInspectionSchema {
pub pack_count: usize,
pub index_count: usize,
pub unpaired_pack_count: usize,
pub pending_install_intents: usize,
}Fields
pack_count: usizeindex_count: usizeunpaired_pack_count: usizepending_install_intents: usizeTrait Implementations
Sourceimpl Debug for PackFilesInspectionSchema
impl Debug for PackFilesInspectionSchema
Sourceimpl JsonSchema for PackFilesInspectionSchema
impl JsonSchema for PackFilesInspectionSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PackFilesInspectionSchema
impl RefUnwindSafe for PackFilesInspectionSchema
impl Send for PackFilesInspectionSchema
impl Sync for PackFilesInspectionSchema
impl Unpin for PackFilesInspectionSchema
impl UnsafeUnpin for PackFilesInspectionSchema
impl UnwindSafe for PackFilesInspectionSchema