pub struct PackInstallMetricsSchema {
pub installs_ok: u64,
pub installs_err: u64,
pub recover_completed: u64,
pub recover_aborted: u64,
pub recover_skipped_in_progress: u64,
pub recover_quarantined: u64,
}Fields
installs_ok: u64installs_err: u64recover_completed: u64recover_aborted: u64recover_skipped_in_progress: u64recover_quarantined: u64Trait Implementations
Sourceimpl Debug for PackInstallMetricsSchema
impl Debug for PackInstallMetricsSchema
Sourceimpl JsonSchema for PackInstallMetricsSchema
impl JsonSchema for PackInstallMetricsSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PackInstallMetricsSchema
impl RefUnwindSafe for PackInstallMetricsSchema
impl Send for PackInstallMetricsSchema
impl Sync for PackInstallMetricsSchema
impl Unpin for PackInstallMetricsSchema
impl UnsafeUnpin for PackInstallMetricsSchema
impl UnwindSafe for PackInstallMetricsSchema