pub struct PartialFetchInspectionSchema {
pub count: usize,
pub missing_blob_count: usize,
}Fields
count: usizemissing_blob_count: usizeTrait Implementations
Sourceimpl Debug for PartialFetchInspectionSchema
impl Debug for PartialFetchInspectionSchema
Sourceimpl JsonSchema for PartialFetchInspectionSchema
impl JsonSchema for PartialFetchInspectionSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PartialFetchInspectionSchema
impl RefUnwindSafe for PartialFetchInspectionSchema
impl Send for PartialFetchInspectionSchema
impl Sync for PartialFetchInspectionSchema
impl Unpin for PartialFetchInspectionSchema
impl UnsafeUnpin for PartialFetchInspectionSchema
impl UnwindSafe for PartialFetchInspectionSchema