pub struct PullGitSchema {Show 20 fields
pub output_kind: String,
pub action: String,
pub status: String,
pub pulled: bool,
pub changed: bool,
pub success: bool,
pub transport: GitTransportSchema,
pub remote: String,
pub branch: String,
pub old_git_head: Option<String>,
pub new_git_head: String,
pub old_state: Option<String>,
pub new_state: String,
pub states_created: usize,
pub commits_seen: usize,
pub commits_seen_scope: String,
pub materialized_checkout: bool,
pub changed_path_count: usize,
pub changed_paths: Vec<String>,
pub verification: RepositoryVerificationStateSchema,
}Fields
output_kind: Stringaction: Stringstatus: Stringpulled: boolchanged: boolsuccess: booltransport: GitTransportSchemaremote: Stringbranch: Stringold_git_head: Option<String>new_git_head: Stringold_state: Option<String>new_state: Stringstates_created: usizecommits_seen: usizecommits_seen_scope: Stringmaterialized_checkout: boolchanged_path_count: usizechanged_paths: Vec<String>verification: RepositoryVerificationStateSchemaTrait Implementations
Sourceimpl Debug for PullGitSchema
impl Debug for PullGitSchema
Sourceimpl JsonSchema for PullGitSchema
impl JsonSchema for PullGitSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PullGitSchema
impl RefUnwindSafe for PullGitSchema
impl Send for PullGitSchema
impl Sync for PullGitSchema
impl Unpin for PullGitSchema
impl UnsafeUnpin for PullGitSchema
impl UnwindSafe for PullGitSchema