pub struct PullPlannerCacheInspectionSchema {
pub status: String,
pub present: bool,
pub manifest_count: usize,
pub planner_entry_count: usize,
pub total_bytes: u64,
}Fields
status: Stringpresent: boolmanifest_count: usizeplanner_entry_count: usizetotal_bytes: u64Trait Implementations
Sourceimpl JsonSchema for PullPlannerCacheInspectionSchema
impl JsonSchema for PullPlannerCacheInspectionSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PullPlannerCacheInspectionSchema
impl RefUnwindSafe for PullPlannerCacheInspectionSchema
impl Send for PullPlannerCacheInspectionSchema
impl Sync for PullPlannerCacheInspectionSchema
impl Unpin for PullPlannerCacheInspectionSchema
impl UnsafeUnpin for PullPlannerCacheInspectionSchema
impl UnwindSafe for PullPlannerCacheInspectionSchema