pub struct PushGitSchema {Show 23 fields
pub output_kind: String,
pub action: String,
pub status: String,
pub pushed: bool,
pub changed: bool,
pub success: bool,
pub transport: GitTransportSchema,
pub remote: String,
pub push_scope: String,
pub ref_scope: String,
pub refs_written: Vec<String>,
pub git_tracking_remote: Option<String>,
pub git_remote_configured: Option<GitRemoteConfiguredSchema>,
pub git_upstream_configured: Option<GitUpstreamConfiguredSchema>,
pub tags_included: bool,
pub force: bool,
pub force_discard_warning: Option<String>,
pub thread: Option<String>,
pub next_action: NullableStringSchema,
pub next_action_template: NullableActionTemplateSchema,
pub recommended_action: NullableStringSchema,
pub recommended_action_template: NullableActionTemplateSchema,
pub verification: RepositoryVerificationStateSchema,
}Fields
output_kind: Stringaction: Stringstatus: Stringpushed: boolchanged: boolsuccess: booltransport: GitTransportSchemaremote: Stringpush_scope: Stringref_scope: Stringrefs_written: Vec<String>git_tracking_remote: Option<String>git_remote_configured: Option<GitRemoteConfiguredSchema>git_upstream_configured: Option<GitUpstreamConfiguredSchema>force: boolforce_discard_warning: Option<String>thread: Option<String>next_action: NullableStringSchemanext_action_template: NullableActionTemplateSchemarecommended_action: NullableStringSchemarecommended_action_template: NullableActionTemplateSchemaverification: RepositoryVerificationStateSchemaTrait Implementations
Sourceimpl Debug for PushGitSchema
impl Debug for PushGitSchema
Sourceimpl JsonSchema for PushGitSchema
impl JsonSchema for PushGitSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PushGitSchema
impl RefUnwindSafe for PushGitSchema
impl Send for PushGitSchema
impl Sync for PushGitSchema
impl Unpin for PushGitSchema
impl UnsafeUnpin for PushGitSchema
impl UnwindSafe for PushGitSchema