pub struct ReadyChecksSchema {
pub status: String,
pub reason: String,
}Fields
status: Stringreason: StringTrait Implementations
Sourceimpl Debug for ReadyChecksSchema
impl Debug for ReadyChecksSchema
Sourceimpl JsonSchema for ReadyChecksSchema
impl JsonSchema for ReadyChecksSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReadyChecksSchema
impl RefUnwindSafe for ReadyChecksSchema
impl Send for ReadyChecksSchema
impl Sync for ReadyChecksSchema
impl Unpin for ReadyChecksSchema
impl UnsafeUnpin for ReadyChecksSchema
impl UnwindSafe for ReadyChecksSchema