pub struct ReadySchema {Show 16 fields
pub output_kind: Option<String>,
pub status: String,
pub action: String,
pub message: String,
pub blockers: Vec<String>,
pub warnings: Vec<String>,
pub next_action: Option<String>,
pub next_action_template: Option<ActionTemplateSchema>,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub captured: bool,
pub captured_state: Option<String>,
pub thread_state: Option<String>,
pub readiness: ReadyReadinessSchema,
pub report: Value,
pub verification: RepositoryVerificationStateSchema,
}Fields
output_kind: Option<String>status: Stringaction: Stringmessage: Stringblockers: Vec<String>warnings: Vec<String>next_action: Option<String>next_action_template: Option<ActionTemplateSchema>recommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>captured: boolcaptured_state: Option<String>thread_state: Option<String>readiness: ReadyReadinessSchemareport: Valueverification: RepositoryVerificationStateSchemaTrait Implementations
Sourceimpl Debug for ReadySchema
impl Debug for ReadySchema
Sourceimpl JsonSchema for ReadySchema
impl JsonSchema for ReadySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReadySchema
impl RefUnwindSafe for ReadySchema
impl Send for ReadySchema
impl Sync for ReadySchema
impl Unpin for ReadySchema
impl UnsafeUnpin for ReadySchema
impl UnwindSafe for ReadySchema