pub struct RefCountsInspectionSchema {
pub total: usize,
pub threads: usize,
pub markers: usize,
pub remotes: usize,
pub remote_threads: usize,
pub packed_refs_present: bool,
pub packed_refs_bytes: u64,
}Fields
total: usizethreads: usizemarkers: usizeremotes: usizeremote_threads: usizepacked_refs_present: boolpacked_refs_bytes: u64Trait Implementations
Sourceimpl Debug for RefCountsInspectionSchema
impl Debug for RefCountsInspectionSchema
Sourceimpl JsonSchema for RefCountsInspectionSchema
impl JsonSchema for RefCountsInspectionSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RefCountsInspectionSchema
impl RefUnwindSafe for RefCountsInspectionSchema
impl Send for RefCountsInspectionSchema
impl Sync for RefCountsInspectionSchema
impl Unpin for RefCountsInspectionSchema
impl UnsafeUnpin for RefCountsInspectionSchema
impl UnwindSafe for RefCountsInspectionSchema