pub struct RemoteInfoSchema {
pub output_kind: Option<String>,
pub name: String,
pub url: String,
pub source: String,
pub is_default: bool,
}Fields
output_kind: Option<String>name: Stringurl: Stringsource: Stringis_default: boolTrait Implementations
Sourceimpl Debug for RemoteInfoSchema
impl Debug for RemoteInfoSchema
Sourceimpl JsonSchema for RemoteInfoSchema
impl JsonSchema for RemoteInfoSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RemoteInfoSchema
impl RefUnwindSafe for RemoteInfoSchema
impl Send for RemoteInfoSchema
impl Sync for RemoteInfoSchema
impl Unpin for RemoteInfoSchema
impl UnsafeUnpin for RemoteInfoSchema
impl UnwindSafe for RemoteInfoSchema