pub struct RemoteListSchema {
pub output_kind: Option<String>,
pub remotes: Vec<RemoteInfoSchema>,
}Fields
output_kind: Option<String>remotes: Vec<RemoteInfoSchema>Trait Implementations
Sourceimpl Debug for RemoteListSchema
impl Debug for RemoteListSchema
Sourceimpl JsonSchema for RemoteListSchema
impl JsonSchema for RemoteListSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RemoteListSchema
impl RefUnwindSafe for RemoteListSchema
impl Send for RemoteListSchema
impl Sync for RemoteListSchema
impl Unpin for RemoteListSchema
impl UnsafeUnpin for RemoteListSchema
impl UnwindSafe for RemoteListSchema