pub struct RemoteMutationSchema {
pub output_kind: Option<String>,
pub status: String,
pub action: String,
pub name: String,
pub url: Option<String>,
pub default: Option<String>,
pub message: String,
pub verification: RepositoryVerificationStateSchema,
}Fields
output_kind: Option<String>status: Stringaction: Stringname: Stringurl: Option<String>default: Option<String>message: Stringverification: RepositoryVerificationStateSchemaTrait Implementations
Sourceimpl Debug for RemoteMutationSchema
impl Debug for RemoteMutationSchema
Sourceimpl JsonSchema for RemoteMutationSchema
impl JsonSchema for RemoteMutationSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RemoteMutationSchema
impl RefUnwindSafe for RemoteMutationSchema
impl Send for RemoteMutationSchema
impl Sync for RemoteMutationSchema
impl Unpin for RemoteMutationSchema
impl UnsafeUnpin for RemoteMutationSchema
impl UnwindSafe for RemoteMutationSchema