pub struct RepositoryContextInfoSchema {
pub kind: String,
pub parent_repository: Option<String>,
pub target_thread: Option<String>,
pub parent_thread: Option<String>,
}Fields
kind: Stringparent_repository: Option<String>target_thread: Option<String>parent_thread: Option<String>Trait Implementations
Sourceimpl Debug for RepositoryContextInfoSchema
impl Debug for RepositoryContextInfoSchema
Sourceimpl JsonSchema for RepositoryContextInfoSchema
impl JsonSchema for RepositoryContextInfoSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RepositoryContextInfoSchema
impl RefUnwindSafe for RepositoryContextInfoSchema
impl Send for RepositoryContextInfoSchema
impl Sync for RepositoryContextInfoSchema
impl Unpin for RepositoryContextInfoSchema
impl UnsafeUnpin for RepositoryContextInfoSchema
impl UnwindSafe for RepositoryContextInfoSchema