pub struct RepositoryVerificationStateSchema {Show 24 fields
pub verified: bool,
pub status: String,
pub repository_mode: String,
pub heddle_initialized: bool,
pub git_branch: Option<String>,
pub heddle_thread: Option<String>,
pub worktree_dirty: bool,
pub worktree_state: String,
pub import_state: String,
pub mapping_state: String,
pub remote_drift: String,
pub active_operation: Option<String>,
pub default_remote: Option<String>,
pub clone_verification: String,
pub machine_contract: String,
pub machine_contract_coverage: MachineContractCoverageSchema,
pub workflow_status: String,
pub workflow_summary: String,
pub summary: String,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub recovery_commands: Vec<String>,
pub recovery_action_templates: Vec<ActionTemplateSchema>,
pub checks: Vec<VerificationCheckSchema>,
}Fields
verified: boolstatus: Stringrepository_mode: Stringheddle_initialized: boolgit_branch: Option<String>heddle_thread: Option<String>worktree_dirty: boolworktree_state: Stringimport_state: Stringmapping_state: Stringremote_drift: Stringactive_operation: Option<String>default_remote: Option<String>clone_verification: Stringmachine_contract: Stringmachine_contract_coverage: MachineContractCoverageSchemaworkflow_status: Stringworkflow_summary: Stringsummary: Stringrecommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>recovery_commands: Vec<String>recovery_action_templates: Vec<ActionTemplateSchema>checks: Vec<VerificationCheckSchema>Trait Implementations
Sourceimpl JsonSchema for RepositoryVerificationStateSchema
impl JsonSchema for RepositoryVerificationStateSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RepositoryVerificationStateSchema
impl RefUnwindSafe for RepositoryVerificationStateSchema
impl Send for RepositoryVerificationStateSchema
impl Sync for RepositoryVerificationStateSchema
impl Unpin for RepositoryVerificationStateSchema
impl UnsafeUnpin for RepositoryVerificationStateSchema
impl UnwindSafe for RepositoryVerificationStateSchema