pub struct ResolveSchema {
pub output_kind: String,
pub message: Option<String>,
pub resolved: Option<Vec<String>>,
pub remaining: Option<Vec<String>>,
pub conflicts: Option<Vec<String>>,
pub continued: Option<bool>,
pub continuation_status: Option<String>,
pub continuation_message: Option<String>,
pub next_action: Option<String>,
pub recommended_action: Option<String>,
}Fields
output_kind: Stringmessage: Option<String>resolved: Option<Vec<String>>remaining: Option<Vec<String>>conflicts: Option<Vec<String>>continued: Option<bool>continuation_status: Option<String>continuation_message: Option<String>next_action: Option<String>recommended_action: Option<String>Trait Implementations
Sourceimpl Debug for ResolveSchema
impl Debug for ResolveSchema
Sourceimpl JsonSchema for ResolveSchema
impl JsonSchema for ResolveSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ResolveSchema
impl RefUnwindSafe for ResolveSchema
impl Send for ResolveSchema
impl Sync for ResolveSchema
impl Unpin for ResolveSchema
impl UnsafeUnpin for ResolveSchema
impl UnwindSafe for ResolveSchema