pub struct RetroAgentEntrySchema {
pub session_id: String,
pub provider: Option<String>,
pub model: Option<String>,
pub status: String,
pub started_at: String,
pub completed_at: Option<String>,
pub tokens: RetroAgentTokensSchema,
}Fields
session_id: Stringprovider: Option<String>model: Option<String>status: Stringstarted_at: Stringcompleted_at: Option<String>tokens: RetroAgentTokensSchemaTrait Implementations
Sourceimpl Debug for RetroAgentEntrySchema
impl Debug for RetroAgentEntrySchema
Sourceimpl JsonSchema for RetroAgentEntrySchema
impl JsonSchema for RetroAgentEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetroAgentEntrySchema
impl RefUnwindSafe for RetroAgentEntrySchema
impl Send for RetroAgentEntrySchema
impl Sync for RetroAgentEntrySchema
impl Unpin for RetroAgentEntrySchema
impl UnsafeUnpin for RetroAgentEntrySchema
impl UnwindSafe for RetroAgentEntrySchema