pub struct RetroAgentTaskEntrySchema {
pub task_id: String,
pub title: String,
pub status: String,
pub target_thread: String,
pub updated_at: String,
pub completed_at: Option<String>,
pub coordination_discussion_id: Option<String>,
}Fields
task_id: Stringtitle: Stringstatus: Stringtarget_thread: Stringupdated_at: Stringcompleted_at: Option<String>coordination_discussion_id: Option<String>Trait Implementations
Sourceimpl Debug for RetroAgentTaskEntrySchema
impl Debug for RetroAgentTaskEntrySchema
Sourceimpl JsonSchema for RetroAgentTaskEntrySchema
impl JsonSchema for RetroAgentTaskEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetroAgentTaskEntrySchema
impl RefUnwindSafe for RetroAgentTaskEntrySchema
impl Send for RetroAgentTaskEntrySchema
impl Sync for RetroAgentTaskEntrySchema
impl Unpin for RetroAgentTaskEntrySchema
impl UnsafeUnpin for RetroAgentTaskEntrySchema
impl UnwindSafe for RetroAgentTaskEntrySchema