pub struct RetroAgentTokensSchema {
pub input: Option<u64>,
pub output: Option<u64>,
pub reasoning: Option<u64>,
pub tool_calls: Option<u32>,
}Fields
input: Option<u64>output: Option<u64>reasoning: Option<u64>tool_calls: Option<u32>Trait Implementations
Sourceimpl Debug for RetroAgentTokensSchema
impl Debug for RetroAgentTokensSchema
Sourceimpl JsonSchema for RetroAgentTokensSchema
impl JsonSchema for RetroAgentTokensSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetroAgentTokensSchema
impl RefUnwindSafe for RetroAgentTokensSchema
impl Send for RetroAgentTokensSchema
impl Sync for RetroAgentTokensSchema
impl Unpin for RetroAgentTokensSchema
impl UnsafeUnpin for RetroAgentTokensSchema
impl UnwindSafe for RetroAgentTokensSchema