pub struct RetroContextAnnotationEntrySchema {
pub path: String,
pub scope: String,
pub kind: String,
pub content_excerpt: String,
pub attribution: String,
pub created_at: String,
}Fields
path: Stringscope: Stringkind: Stringcontent_excerpt: Stringattribution: Stringcreated_at: StringTrait Implementations
Sourceimpl JsonSchema for RetroContextAnnotationEntrySchema
impl JsonSchema for RetroContextAnnotationEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetroContextAnnotationEntrySchema
impl RefUnwindSafe for RetroContextAnnotationEntrySchema
impl Send for RetroContextAnnotationEntrySchema
impl Sync for RetroContextAnnotationEntrySchema
impl Unpin for RetroContextAnnotationEntrySchema
impl UnsafeUnpin for RetroContextAnnotationEntrySchema
impl UnwindSafe for RetroContextAnnotationEntrySchema