pub struct RetroMarkerEntrySchema {
pub name: String,
pub state: String,
pub timestamp: String,
}Fields
name: Stringstate: Stringtimestamp: StringTrait Implementations
Sourceimpl Debug for RetroMarkerEntrySchema
impl Debug for RetroMarkerEntrySchema
Sourceimpl JsonSchema for RetroMarkerEntrySchema
impl JsonSchema for RetroMarkerEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetroMarkerEntrySchema
impl RefUnwindSafe for RetroMarkerEntrySchema
impl Send for RetroMarkerEntrySchema
impl Sync for RetroMarkerEntrySchema
impl Unpin for RetroMarkerEntrySchema
impl UnsafeUnpin for RetroMarkerEntrySchema
impl UnwindSafe for RetroMarkerEntrySchema