pub struct RetroOperationEntrySchema {
pub description: String,
pub timestamp: String,
}Fields
description: Stringtimestamp: StringTrait Implementations
Sourceimpl Debug for RetroOperationEntrySchema
impl Debug for RetroOperationEntrySchema
Sourceimpl JsonSchema for RetroOperationEntrySchema
impl JsonSchema for RetroOperationEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetroOperationEntrySchema
impl RefUnwindSafe for RetroOperationEntrySchema
impl Send for RetroOperationEntrySchema
impl Sync for RetroOperationEntrySchema
impl Unpin for RetroOperationEntrySchema
impl UnsafeUnpin for RetroOperationEntrySchema
impl UnwindSafe for RetroOperationEntrySchema