pub struct RetroSchema {
pub since: Option<String>,
pub until: Option<String>,
pub duration_secs: Option<i64>,
pub states_captured: Vec<RetroStateEntrySchema>,
pub agents_active: Vec<RetroAgentEntrySchema>,
pub agent_tasks: Vec<RetroAgentTaskEntrySchema>,
pub timeline_steps: Vec<RetroTimelineStepEntrySchema>,
pub markers_created: Vec<RetroMarkerEntrySchema>,
pub context_annotations: Vec<RetroContextAnnotationEntrySchema>,
pub verify_signals: Vec<RetroVerifySignalSchema>,
pub merges: Vec<RetroOperationEntrySchema>,
pub undos: Vec<RetroOperationEntrySchema>,
}Fields
since: Option<String>until: Option<String>duration_secs: Option<i64>states_captured: Vec<RetroStateEntrySchema>agents_active: Vec<RetroAgentEntrySchema>agent_tasks: Vec<RetroAgentTaskEntrySchema>timeline_steps: Vec<RetroTimelineStepEntrySchema>markers_created: Vec<RetroMarkerEntrySchema>context_annotations: Vec<RetroContextAnnotationEntrySchema>verify_signals: Vec<RetroVerifySignalSchema>merges: Vec<RetroOperationEntrySchema>undos: Vec<RetroOperationEntrySchema>Trait Implementations
Sourceimpl Debug for RetroSchema
impl Debug for RetroSchema
Sourceimpl JsonSchema for RetroSchema
impl JsonSchema for RetroSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetroSchema
impl RefUnwindSafe for RetroSchema
impl Send for RetroSchema
impl Sync for RetroSchema
impl Unpin for RetroSchema
impl UnsafeUnpin for RetroSchema
impl UnwindSafe for RetroSchema