pub struct RetroStateEntrySchema {
pub state_id: String,
pub intent: Option<String>,
pub confidence: Option<f32>,
pub agent: Option<String>,
pub principal: String,
pub timestamp: String,
}Fields
state_id: Stringintent: Option<String>confidence: Option<f32>agent: Option<String>principal: Stringtimestamp: StringTrait Implementations
Sourceimpl Debug for RetroStateEntrySchema
impl Debug for RetroStateEntrySchema
Sourceimpl JsonSchema for RetroStateEntrySchema
impl JsonSchema for RetroStateEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetroStateEntrySchema
impl RefUnwindSafe for RetroStateEntrySchema
impl Send for RetroStateEntrySchema
impl Sync for RetroStateEntrySchema
impl Unpin for RetroStateEntrySchema
impl UnsafeUnpin for RetroStateEntrySchema
impl UnwindSafe for RetroStateEntrySchema