pub struct RetroTimelineStepEntrySchema {Show 14 fields
pub thread: String,
pub step_id: String,
pub branch_id: String,
pub parent_step_id: Option<String>,
pub tool_name: Option<String>,
pub tool_status: Option<String>,
pub changed: Option<bool>,
pub payload_summary: Option<String>,
pub payload_hash: Option<String>,
pub before_state: Option<String>,
pub after_state: Option<String>,
pub capture_state: Option<String>,
pub started_at_ms: Option<i64>,
pub finished_at_ms: Option<i64>,
}Fields
thread: Stringstep_id: Stringbranch_id: Stringparent_step_id: Option<String>tool_name: Option<String>tool_status: Option<String>changed: Option<bool>payload_summary: Option<String>payload_hash: Option<String>before_state: Option<String>after_state: Option<String>capture_state: Option<String>started_at_ms: Option<i64>finished_at_ms: Option<i64>Trait Implementations
Sourceimpl Debug for RetroTimelineStepEntrySchema
impl Debug for RetroTimelineStepEntrySchema
Sourceimpl JsonSchema for RetroTimelineStepEntrySchema
impl JsonSchema for RetroTimelineStepEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetroTimelineStepEntrySchema
impl RefUnwindSafe for RetroTimelineStepEntrySchema
impl Send for RetroTimelineStepEntrySchema
impl Sync for RetroTimelineStepEntrySchema
impl Unpin for RetroTimelineStepEntrySchema
impl UnsafeUnpin for RetroTimelineStepEntrySchema
impl UnwindSafe for RetroTimelineStepEntrySchema