pub struct RetroVerifySignalSchema {
pub kind: String,
pub label: String,
pub timestamp: String,
}Fields
kind: Stringlabel: Stringtimestamp: StringTrait Implementations
Sourceimpl Debug for RetroVerifySignalSchema
impl Debug for RetroVerifySignalSchema
Sourceimpl JsonSchema for RetroVerifySignalSchema
impl JsonSchema for RetroVerifySignalSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RetroVerifySignalSchema
impl RefUnwindSafe for RetroVerifySignalSchema
impl Send for RetroVerifySignalSchema
impl Sync for RetroVerifySignalSchema
impl Unpin for RetroVerifySignalSchema
impl UnsafeUnpin for RetroVerifySignalSchema
impl UnwindSafe for RetroVerifySignalSchema