pub struct ReviewHealthEntrySchema {
pub module_id: String,
pub fire_rate: f64,
pub warn: bool,
}Fields
module_id: Stringfire_rate: f64warn: boolTrait Implementations
Sourceimpl Debug for ReviewHealthEntrySchema
impl Debug for ReviewHealthEntrySchema
Sourceimpl JsonSchema for ReviewHealthEntrySchema
impl JsonSchema for ReviewHealthEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReviewHealthEntrySchema
impl RefUnwindSafe for ReviewHealthEntrySchema
impl Send for ReviewHealthEntrySchema
impl Sync for ReviewHealthEntrySchema
impl Unpin for ReviewHealthEntrySchema
impl UnsafeUnpin for ReviewHealthEntrySchema
impl UnwindSafe for ReviewHealthEntrySchema