pub struct ReviewHealthSchema {
pub output_kind: String,
pub entries: Vec<ReviewHealthEntrySchema>,
pub window_states: usize,
}Fields
output_kind: Stringentries: Vec<ReviewHealthEntrySchema>window_states: usizeTrait Implementations
Sourceimpl Debug for ReviewHealthSchema
impl Debug for ReviewHealthSchema
Sourceimpl JsonSchema for ReviewHealthSchema
impl JsonSchema for ReviewHealthSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReviewHealthSchema
impl RefUnwindSafe for ReviewHealthSchema
impl Send for ReviewHealthSchema
impl Sync for ReviewHealthSchema
impl Unpin for ReviewHealthSchema
impl UnsafeUnpin for ReviewHealthSchema
impl UnwindSafe for ReviewHealthSchema