pub struct ReviewNextStateSchema {
pub state_id: String,
pub headline: String,
pub existing_signatures: u32,
}Expand description
The pending review state echoed under review next’s next field.
Fields
state_id: Stringheadline: Stringexisting_signatures: u32Trait Implementations
Sourceimpl Debug for ReviewNextStateSchema
impl Debug for ReviewNextStateSchema
Sourceimpl JsonSchema for ReviewNextStateSchema
impl JsonSchema for ReviewNextStateSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReviewNextStateSchema
impl RefUnwindSafe for ReviewNextStateSchema
impl Send for ReviewNextStateSchema
impl Sync for ReviewNextStateSchema
impl Unpin for ReviewNextStateSchema
impl UnsafeUnpin for ReviewNextStateSchema
impl UnwindSafe for ReviewNextStateSchema