pub struct ReviewSignSchema {
pub output_kind: String,
pub signature_id: String,
pub state_id: String,
}Fields
output_kind: Stringsignature_id: Stringstate_id: StringTrait Implementations
Sourceimpl Debug for ReviewSignSchema
impl Debug for ReviewSignSchema
Sourceimpl JsonSchema for ReviewSignSchema
impl JsonSchema for ReviewSignSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReviewSignSchema
impl RefUnwindSafe for ReviewSignSchema
impl Send for ReviewSignSchema
impl Sync for ReviewSignSchema
impl Unpin for ReviewSignSchema
impl UnsafeUnpin for ReviewSignSchema
impl UnwindSafe for ReviewSignSchema