pub struct SchemasListSchema {
pub output_kind: Option<String>,
pub status: Option<String>,
pub schema_verbs: Vec<String>,
pub documented_schema_verbs: Vec<String>,
}Fields
output_kind: Option<String>status: Option<String>schema_verbs: Vec<String>documented_schema_verbs: Vec<String>Trait Implementations
Sourceimpl Debug for SchemasListSchema
impl Debug for SchemasListSchema
Sourceimpl JsonSchema for SchemasListSchema
impl JsonSchema for SchemasListSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SchemasListSchema
impl RefUnwindSafe for SchemasListSchema
impl Send for SchemasListSchema
impl Sync for SchemasListSchema
impl Unpin for SchemasListSchema
impl UnsafeUnpin for SchemasListSchema
impl UnwindSafe for SchemasListSchema