pub struct SessionEntrySchema {
pub id: String,
pub principal: String,
pub created_at: String,
pub ended_at: Option<String>,
pub active: bool,
pub segments: Vec<SessionSegmentSchema>,
}Fields
id: Stringprincipal: Stringcreated_at: Stringended_at: Option<String>active: boolsegments: Vec<SessionSegmentSchema>Trait Implementations
Sourceimpl Debug for SessionEntrySchema
impl Debug for SessionEntrySchema
Sourceimpl JsonSchema for SessionEntrySchema
impl JsonSchema for SessionEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionEntrySchema
impl RefUnwindSafe for SessionEntrySchema
impl Send for SessionEntrySchema
impl Sync for SessionEntrySchema
impl Unpin for SessionEntrySchema
impl UnsafeUnpin for SessionEntrySchema
impl UnwindSafe for SessionEntrySchema