pub struct SessionSegmentSchema {
pub id: String,
pub provider: String,
pub model: String,
pub started_at: String,
pub policy_id: Option<String>,
}Fields
id: Stringprovider: Stringmodel: Stringstarted_at: Stringpolicy_id: Option<String>Trait Implementations
Sourceimpl Debug for SessionSegmentSchema
impl Debug for SessionSegmentSchema
Sourceimpl JsonSchema for SessionSegmentSchema
impl JsonSchema for SessionSegmentSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SessionSegmentSchema
impl RefUnwindSafe for SessionSegmentSchema
impl Send for SessionSegmentSchema
impl Sync for SessionSegmentSchema
impl Unpin for SessionSegmentSchema
impl UnsafeUnpin for SessionSegmentSchema
impl UnwindSafe for SessionSegmentSchema