pub struct ShowAgentSchema {
pub provider: Option<String>,
pub model: Option<String>,
pub session_id: Option<String>,
pub policy_id: Option<String>,
}Fields
provider: Option<String>model: Option<String>session_id: Option<String>policy_id: Option<String>Trait Implementations
Sourceimpl Debug for ShowAgentSchema
impl Debug for ShowAgentSchema
Sourceimpl JsonSchema for ShowAgentSchema
impl JsonSchema for ShowAgentSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShowAgentSchema
impl RefUnwindSafe for ShowAgentSchema
impl Send for ShowAgentSchema
impl Sync for ShowAgentSchema
impl Unpin for ShowAgentSchema
impl UnsafeUnpin for ShowAgentSchema
impl UnwindSafe for ShowAgentSchema