pub struct ShowSchema {Show 16 fields
pub output_kind: String,
pub repository_capability: String,
pub storage_model: String,
pub state_id: String,
pub state_id_full: String,
pub content_hash: String,
pub tree: String,
pub parents: Vec<String>,
pub intent: Option<String>,
pub confidence: Option<f32>,
pub principal: ShowPrincipalSchema,
pub agent: Option<ShowAgentSchema>,
pub created_at: String,
pub status: String,
pub verification: Option<Value>,
pub git_checkpoint: Option<String>,
}Fields
output_kind: Stringrepository_capability: Stringstorage_model: Stringstate_id: Stringstate_id_full: Stringcontent_hash: Stringtree: Stringparents: Vec<String>intent: Option<String>confidence: Option<f32>principal: ShowPrincipalSchemaagent: Option<ShowAgentSchema>created_at: Stringstatus: Stringverification: Option<Value>git_checkpoint: Option<String>Trait Implementations
Sourceimpl Debug for ShowSchema
impl Debug for ShowSchema
Sourceimpl JsonSchema for ShowSchema
impl JsonSchema for ShowSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ShowSchema
impl RefUnwindSafe for ShowSchema
impl Send for ShowSchema
impl Sync for ShowSchema
impl Unpin for ShowSchema
impl UnsafeUnpin for ShowSchema
impl UnwindSafe for ShowSchema