pub struct SiblingRestackFailureSchema {
pub thread: String,
pub message: String,
}Fields
thread: Stringmessage: StringTrait Implementations
Sourceimpl Debug for SiblingRestackFailureSchema
impl Debug for SiblingRestackFailureSchema
Sourceimpl JsonSchema for SiblingRestackFailureSchema
impl JsonSchema for SiblingRestackFailureSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SiblingRestackFailureSchema
impl RefUnwindSafe for SiblingRestackFailureSchema
impl Send for SiblingRestackFailureSchema
impl Sync for SiblingRestackFailureSchema
impl Unpin for SiblingRestackFailureSchema
impl UnsafeUnpin for SiblingRestackFailureSchema
impl UnwindSafe for SiblingRestackFailureSchema