pub struct StateEntrySchema {
pub state_id: String,
pub content_hash: String,
pub intent: Option<String>,
pub principal: String,
pub agent: Option<String>,
pub confidence: Option<f32>,
pub created_at: String,
pub parents: Vec<String>,
pub git_checkpoint: Option<String>,
pub collapsed: Option<CollapsedEntrySchema>,
}Fields
state_id: Stringcontent_hash: Stringintent: Option<String>principal: Stringagent: Option<String>confidence: Option<f32>created_at: Stringparents: Vec<String>git_checkpoint: Option<String>collapsed: Option<CollapsedEntrySchema>Trait Implementations
Sourceimpl Debug for StateEntrySchema
impl Debug for StateEntrySchema
Sourceimpl JsonSchema for StateEntrySchema
impl JsonSchema for StateEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StateEntrySchema
impl RefUnwindSafe for StateEntrySchema
impl Send for StateEntrySchema
impl Sync for StateEntrySchema
impl Unpin for StateEntrySchema
impl UnsafeUnpin for StateEntrySchema
impl UnwindSafe for StateEntrySchema