pub struct SyncSchema {
pub operator: OperatorCommandSchema,
pub thread: Option<String>,
pub current_state: Option<String>,
pub chosen_path: Option<String>,
}Fields
operator: OperatorCommandSchemathread: Option<String>current_state: Option<String>chosen_path: Option<String>Trait Implementations
Sourceimpl Debug for SyncSchema
impl Debug for SyncSchema
Sourceimpl JsonSchema for SyncSchema
impl JsonSchema for SyncSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for SyncSchema
impl RefUnwindSafe for SyncSchema
impl Send for SyncSchema
impl Sync for SyncSchema
impl Unpin for SyncSchema
impl UnsafeUnpin for SyncSchema
impl UnwindSafe for SyncSchema