pub struct ThreadAbsorbSchema {
pub thread: String,
pub into: String,
pub preview_only: bool,
pub conflicts: Vec<String>,
pub merge_state: Option<String>,
pub message: String,
}Fields
thread: Stringinto: Stringpreview_only: boolconflicts: Vec<String>merge_state: Option<String>message: StringTrait Implementations
Sourceimpl Debug for ThreadAbsorbSchema
impl Debug for ThreadAbsorbSchema
Sourceimpl JsonSchema for ThreadAbsorbSchema
impl JsonSchema for ThreadAbsorbSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadAbsorbSchema
impl RefUnwindSafe for ThreadAbsorbSchema
impl Send for ThreadAbsorbSchema
impl Sync for ThreadAbsorbSchema
impl Unpin for ThreadAbsorbSchema
impl UnsafeUnpin for ThreadAbsorbSchema
impl UnwindSafe for ThreadAbsorbSchema