pub struct ThreadApprovalListSchema(pub Vec<ThreadApprovalSchema>);Tuple Fields
0: Vec<ThreadApprovalSchema>Trait Implementations
Sourceimpl Debug for ThreadApprovalListSchema
impl Debug for ThreadApprovalListSchema
Sourceimpl JsonSchema for ThreadApprovalListSchema
impl JsonSchema for ThreadApprovalListSchema
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more