pub struct ThreadApprovalSchema {
pub id: String,
pub repo_path: String,
pub source_thread: String,
pub target_thread: String,
pub source_state: String,
pub approver_user_id: String,
pub note: String,
pub approved_at: u64,
pub expires_at: u64,
}Fields
id: Stringrepo_path: Stringsource_thread: Stringtarget_thread: Stringsource_state: Stringapprover_user_id: Stringnote: Stringapproved_at: u64expires_at: u64Trait Implementations
Sourceimpl Debug for ThreadApprovalSchema
impl Debug for ThreadApprovalSchema
Sourceimpl JsonSchema for ThreadApprovalSchema
impl JsonSchema for ThreadApprovalSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadApprovalSchema
impl RefUnwindSafe for ThreadApprovalSchema
impl Send for ThreadApprovalSchema
impl Sync for ThreadApprovalSchema
impl Unpin for ThreadApprovalSchema
impl UnsafeUnpin for ThreadApprovalSchema
impl UnwindSafe for ThreadApprovalSchema