pub struct ThreadCaptureEntrySchema {
pub state_id: String,
pub created_at: String,
pub intent: Option<String>,
pub confidence: Option<f32>,
pub agent: Option<String>,
pub message: String,
pub summary: Option<ThreadCaptureSummarySchema>,
}Fields
state_id: Stringcreated_at: Stringintent: Option<String>confidence: Option<f32>agent: Option<String>message: Stringsummary: Option<ThreadCaptureSummarySchema>Trait Implementations
Sourceimpl Debug for ThreadCaptureEntrySchema
impl Debug for ThreadCaptureEntrySchema
Sourceimpl JsonSchema for ThreadCaptureEntrySchema
impl JsonSchema for ThreadCaptureEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadCaptureEntrySchema
impl RefUnwindSafe for ThreadCaptureEntrySchema
impl Send for ThreadCaptureEntrySchema
impl Sync for ThreadCaptureEntrySchema
impl Unpin for ThreadCaptureEntrySchema
impl UnsafeUnpin for ThreadCaptureEntrySchema
impl UnwindSafe for ThreadCaptureEntrySchema