pub struct ThreadCaptureSummarySchema {
pub added: usize,
pub modified: usize,
pub deleted: usize,
pub total: usize,
}Fields
added: usizemodified: usizedeleted: usizetotal: usizeTrait Implementations
Sourceimpl Debug for ThreadCaptureSummarySchema
impl Debug for ThreadCaptureSummarySchema
Sourceimpl JsonSchema for ThreadCaptureSummarySchema
impl JsonSchema for ThreadCaptureSummarySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadCaptureSummarySchema
impl RefUnwindSafe for ThreadCaptureSummarySchema
impl Send for ThreadCaptureSummarySchema
impl Sync for ThreadCaptureSummarySchema
impl Unpin for ThreadCaptureSummarySchema
impl UnsafeUnpin for ThreadCaptureSummarySchema
impl UnwindSafe for ThreadCaptureSummarySchema