pub struct ThreadCapturesSchema(pub Vec<ThreadCaptureEntrySchema>);Tuple Fields
0: Vec<ThreadCaptureEntrySchema>Trait Implementations
Sourceimpl Debug for ThreadCapturesSchema
impl Debug for ThreadCapturesSchema
Sourceimpl JsonSchema for ThreadCapturesSchema
impl JsonSchema for ThreadCapturesSchema
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more