pub struct ThreadCleanupSchema {
pub operator: OperatorCommandSchema,
pub dry_run: bool,
pub merged: Vec<ThreadDroppedSchema>,
pub auto: Vec<ThreadDroppedSchema>,
pub reclaimed_bytes: u64,
pub would_reclaim_bytes: u64,
pub skipped: Vec<ThreadCleanupSkippedSchema>,
}Fields
operator: OperatorCommandSchemadry_run: boolmerged: Vec<ThreadDroppedSchema>auto: Vec<ThreadDroppedSchema>reclaimed_bytes: u64would_reclaim_bytes: u64skipped: Vec<ThreadCleanupSkippedSchema>Trait Implementations
Sourceimpl Debug for ThreadCleanupSchema
impl Debug for ThreadCleanupSchema
Sourceimpl JsonSchema for ThreadCleanupSchema
impl JsonSchema for ThreadCleanupSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadCleanupSchema
impl RefUnwindSafe for ThreadCleanupSchema
impl Send for ThreadCleanupSchema
impl Sync for ThreadCleanupSchema
impl Unpin for ThreadCleanupSchema
impl UnsafeUnpin for ThreadCleanupSchema
impl UnwindSafe for ThreadCleanupSchema