pub struct ThreadCleanupSkippedSchema {
pub thread: String,
pub id: String,
pub reason: String,
pub note: String,
}Fields
thread: Stringid: Stringreason: Stringnote: StringTrait Implementations
Sourceimpl Debug for ThreadCleanupSkippedSchema
impl Debug for ThreadCleanupSkippedSchema
Sourceimpl JsonSchema for ThreadCleanupSkippedSchema
impl JsonSchema for ThreadCleanupSkippedSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadCleanupSkippedSchema
impl RefUnwindSafe for ThreadCleanupSkippedSchema
impl Send for ThreadCleanupSkippedSchema
impl Sync for ThreadCleanupSkippedSchema
impl Unpin for ThreadCleanupSkippedSchema
impl UnsafeUnpin for ThreadCleanupSkippedSchema
impl UnwindSafe for ThreadCleanupSkippedSchema