pub struct ThreadCommandSchema {
pub output_kind: String,
pub status: String,
pub action: String,
pub name: String,
pub message: String,
pub next_action: Option<String>,
pub next_action_template: Option<ActionTemplateSchema>,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub thread: Option<ThreadSummarySchema>,
pub path: Option<String>,
pub execution_path: Option<String>,
}Fields
output_kind: Stringstatus: Stringaction: Stringname: Stringmessage: Stringnext_action: Option<String>next_action_template: Option<ActionTemplateSchema>recommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>thread: Option<ThreadSummarySchema>path: Option<String>execution_path: Option<String>Trait Implementations
Sourceimpl Debug for ThreadCommandSchema
impl Debug for ThreadCommandSchema
Sourceimpl JsonSchema for ThreadCommandSchema
impl JsonSchema for ThreadCommandSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadCommandSchema
impl RefUnwindSafe for ThreadCommandSchema
impl Send for ThreadCommandSchema
impl Sync for ThreadCommandSchema
impl Unpin for ThreadCommandSchema
impl UnsafeUnpin for ThreadCommandSchema
impl UnwindSafe for ThreadCommandSchema