pub struct ThreadCurrentSchema {
pub thread: String,
}Fields
thread: StringTrait Implementations
Sourceimpl Debug for ThreadCurrentSchema
impl Debug for ThreadCurrentSchema
Sourceimpl JsonSchema for ThreadCurrentSchema
impl JsonSchema for ThreadCurrentSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadCurrentSchema
impl RefUnwindSafe for ThreadCurrentSchema
impl Send for ThreadCurrentSchema
impl Sync for ThreadCurrentSchema
impl Unpin for ThreadCurrentSchema
impl UnsafeUnpin for ThreadCurrentSchema
impl UnwindSafe for ThreadCurrentSchema