pub struct ThreadDroppedSchema {
pub thread: String,
pub id: String,
pub reason: String,
pub age_seconds: i64,
pub bytes: u64,
pub execution_path: Option<String>,
}Fields
thread: Stringid: Stringreason: Stringage_seconds: i64bytes: u64execution_path: Option<String>Trait Implementations
Sourceimpl Debug for ThreadDroppedSchema
impl Debug for ThreadDroppedSchema
Sourceimpl JsonSchema for ThreadDroppedSchema
impl JsonSchema for ThreadDroppedSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadDroppedSchema
impl RefUnwindSafe for ThreadDroppedSchema
impl Send for ThreadDroppedSchema
impl Sync for ThreadDroppedSchema
impl Unpin for ThreadDroppedSchema
impl UnsafeUnpin for ThreadDroppedSchema
impl UnwindSafe for ThreadDroppedSchema