pub struct ThreadListSchema {Show 14 fields
pub output_kind: Option<String>,
pub repository_capability: String,
pub repository_label: String,
pub repository_context: Option<RepositoryContextInfoSchema>,
pub storage_model: String,
pub hosted_enabled: bool,
pub threads: Vec<ThreadSummarySchema>,
pub available_git_refs: Vec<AvailableGitRefSchema>,
pub current: Option<String>,
pub trust: RepositoryVerificationStateSchema,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub recovery_commands: Vec<String>,
pub recovery_action_templates: Vec<ActionTemplateSchema>,
}Fields
output_kind: Option<String>repository_capability: Stringrepository_label: Stringrepository_context: Option<RepositoryContextInfoSchema>storage_model: Stringhosted_enabled: boolthreads: Vec<ThreadSummarySchema>available_git_refs: Vec<AvailableGitRefSchema>current: Option<String>trust: RepositoryVerificationStateSchemarecommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>recovery_commands: Vec<String>recovery_action_templates: Vec<ActionTemplateSchema>Trait Implementations
Sourceimpl Debug for ThreadListSchema
impl Debug for ThreadListSchema
Sourceimpl JsonSchema for ThreadListSchema
impl JsonSchema for ThreadListSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadListSchema
impl RefUnwindSafe for ThreadListSchema
impl Send for ThreadListSchema
impl Sync for ThreadListSchema
impl Unpin for ThreadListSchema
impl UnsafeUnpin for ThreadListSchema
impl UnwindSafe for ThreadListSchema