pub struct ThreadMarkerEntrySchema {
pub name: String,
pub state_id: String,
}Fields
name: Stringstate_id: StringTrait Implementations
Sourceimpl Debug for ThreadMarkerEntrySchema
impl Debug for ThreadMarkerEntrySchema
Sourceimpl JsonSchema for ThreadMarkerEntrySchema
impl JsonSchema for ThreadMarkerEntrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadMarkerEntrySchema
impl RefUnwindSafe for ThreadMarkerEntrySchema
impl Send for ThreadMarkerEntrySchema
impl Sync for ThreadMarkerEntrySchema
impl Unpin for ThreadMarkerEntrySchema
impl UnsafeUnpin for ThreadMarkerEntrySchema
impl UnwindSafe for ThreadMarkerEntrySchema