pub struct ThreadMarkerListSchema {
pub output_kind: String,
pub markers: Vec<ThreadMarkerEntrySchema>,
}Fields
output_kind: Stringmarkers: Vec<ThreadMarkerEntrySchema>Trait Implementations
Sourceimpl Debug for ThreadMarkerListSchema
impl Debug for ThreadMarkerListSchema
Sourceimpl JsonSchema for ThreadMarkerListSchema
impl JsonSchema for ThreadMarkerListSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadMarkerListSchema
impl RefUnwindSafe for ThreadMarkerListSchema
impl Send for ThreadMarkerListSchema
impl Sync for ThreadMarkerListSchema
impl Unpin for ThreadMarkerListSchema
impl UnsafeUnpin for ThreadMarkerListSchema
impl UnwindSafe for ThreadMarkerListSchema