pub struct ThreadMarkerOpSchema {
pub output_kind: String,
pub name: Option<String>,
pub state_id: Option<String>,
pub deleted: Option<Vec<ThreadMarkerEntrySchema>>,
pub count: Option<usize>,
pub message: String,
}Fields
output_kind: Stringname: Option<String>state_id: Option<String>deleted: Option<Vec<ThreadMarkerEntrySchema>>count: Option<usize>message: StringTrait Implementations
Sourceimpl Debug for ThreadMarkerOpSchema
impl Debug for ThreadMarkerOpSchema
Sourceimpl JsonSchema for ThreadMarkerOpSchema
impl JsonSchema for ThreadMarkerOpSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadMarkerOpSchema
impl RefUnwindSafe for ThreadMarkerOpSchema
impl Send for ThreadMarkerOpSchema
impl Sync for ThreadMarkerOpSchema
impl Unpin for ThreadMarkerOpSchema
impl UnsafeUnpin for ThreadMarkerOpSchema
impl UnwindSafe for ThreadMarkerOpSchema