pub struct ThreadMergeEligibilitySchema {
pub allowed: bool,
pub unmet: Vec<ThreadMergeRequirementSchema>,
pub valid_approvals: Vec<ThreadApprovalSchema>,
}Fields
allowed: boolunmet: Vec<ThreadMergeRequirementSchema>valid_approvals: Vec<ThreadApprovalSchema>Trait Implementations
Sourceimpl Debug for ThreadMergeEligibilitySchema
impl Debug for ThreadMergeEligibilitySchema
Sourceimpl JsonSchema for ThreadMergeEligibilitySchema
impl JsonSchema for ThreadMergeEligibilitySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadMergeEligibilitySchema
impl RefUnwindSafe for ThreadMergeEligibilitySchema
impl Send for ThreadMergeEligibilitySchema
impl Sync for ThreadMergeEligibilitySchema
impl Unpin for ThreadMergeEligibilitySchema
impl UnsafeUnpin for ThreadMergeEligibilitySchema
impl UnwindSafe for ThreadMergeEligibilitySchema