pub struct ThreadMergeRequirementSchema {
pub policy_id: String,
pub kind: String,
pub group_id: String,
pub reason: String,
pub needed: u32,
pub have: u32,
}Fields
policy_id: Stringkind: Stringgroup_id: Stringreason: Stringneeded: u32have: u32Trait Implementations
Sourceimpl Debug for ThreadMergeRequirementSchema
impl Debug for ThreadMergeRequirementSchema
Sourceimpl JsonSchema for ThreadMergeRequirementSchema
impl JsonSchema for ThreadMergeRequirementSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadMergeRequirementSchema
impl RefUnwindSafe for ThreadMergeRequirementSchema
impl Send for ThreadMergeRequirementSchema
impl Sync for ThreadMergeRequirementSchema
impl Unpin for ThreadMergeRequirementSchema
impl UnsafeUnpin for ThreadMergeRequirementSchema
impl UnwindSafe for ThreadMergeRequirementSchema