pub struct ThreadMoveSchema {
pub from_thread: String,
pub to_thread: String,
pub moved_paths: Vec<String>,
pub source_state_id: Option<String>,
pub target_state_id: String,
pub message: String,
}Fields
from_thread: Stringto_thread: Stringmoved_paths: Vec<String>source_state_id: Option<String>target_state_id: Stringmessage: StringTrait Implementations
Sourceimpl Debug for ThreadMoveSchema
impl Debug for ThreadMoveSchema
Sourceimpl JsonSchema for ThreadMoveSchema
impl JsonSchema for ThreadMoveSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadMoveSchema
impl RefUnwindSafe for ThreadMoveSchema
impl Send for ThreadMoveSchema
impl Sync for ThreadMoveSchema
impl Unpin for ThreadMoveSchema
impl UnsafeUnpin for ThreadMoveSchema
impl UnwindSafe for ThreadMoveSchema