pub struct ThreadResolveSchema {
pub operator: OperatorCommandSchema,
pub thread: String,
}Fields
operator: OperatorCommandSchemathread: StringTrait Implementations
Sourceimpl Debug for ThreadResolveSchema
impl Debug for ThreadResolveSchema
Sourceimpl JsonSchema for ThreadResolveSchema
impl JsonSchema for ThreadResolveSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadResolveSchema
impl RefUnwindSafe for ThreadResolveSchema
impl Send for ThreadResolveSchema
impl Sync for ThreadResolveSchema
impl Unpin for ThreadResolveSchema
impl UnsafeUnpin for ThreadResolveSchema
impl UnwindSafe for ThreadResolveSchema