pub struct ThreadRevokeApprovalSchema {
pub output_kind: String,
pub deleted: bool,
pub id: String,
}Fields
output_kind: Stringdeleted: boolid: StringTrait Implementations
Sourceimpl Debug for ThreadRevokeApprovalSchema
impl Debug for ThreadRevokeApprovalSchema
Sourceimpl JsonSchema for ThreadRevokeApprovalSchema
impl JsonSchema for ThreadRevokeApprovalSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadRevokeApprovalSchema
impl RefUnwindSafe for ThreadRevokeApprovalSchema
impl Send for ThreadRevokeApprovalSchema
impl Sync for ThreadRevokeApprovalSchema
impl Unpin for ThreadRevokeApprovalSchema
impl UnsafeUnpin for ThreadRevokeApprovalSchema
impl UnwindSafe for ThreadRevokeApprovalSchema