pub struct ThreadShowSchema {
pub output_kind: Option<String>,
pub repository_label: String,
pub repository_context: Option<RepositoryContextInfoSchema>,
pub summary: ThreadSummarySchema,
pub next_action: Option<String>,
pub next_action_template: Option<ActionTemplateSchema>,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub trust: RepositoryVerificationStateSchema,
pub recovery_commands: Vec<String>,
}Fields
output_kind: Option<String>repository_label: Stringrepository_context: Option<RepositoryContextInfoSchema>summary: ThreadSummarySchemanext_action: Option<String>next_action_template: Option<ActionTemplateSchema>recommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>trust: RepositoryVerificationStateSchemarecovery_commands: Vec<String>Trait Implementations
Sourceimpl Debug for ThreadShowSchema
impl Debug for ThreadShowSchema
Sourceimpl JsonSchema for ThreadShowSchema
impl JsonSchema for ThreadShowSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadShowSchema
impl RefUnwindSafe for ThreadShowSchema
impl Send for ThreadShowSchema
impl Sync for ThreadShowSchema
impl Unpin for ThreadShowSchema
impl UnsafeUnpin for ThreadShowSchema
impl UnwindSafe for ThreadShowSchema