pub struct ThreadStartSchema {Show 13 fields
pub output_kind: Option<String>,
pub status: Option<String>,
pub action: Option<String>,
pub name: String,
pub message: String,
pub next_action: Option<String>,
pub next_action_template: Option<ActionTemplateSchema>,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub thread: Option<ThreadSummarySchema>,
pub path: Option<String>,
pub execution_path: Option<String>,
pub fskit_readiness: Option<FsKitReadinessSchema>,
}Fields
output_kind: Option<String>status: Option<String>action: Option<String>name: Stringmessage: Stringnext_action: Option<String>next_action_template: Option<ActionTemplateSchema>recommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>thread: Option<ThreadSummarySchema>path: Option<String>execution_path: Option<String>fskit_readiness: Option<FsKitReadinessSchema>Trait Implementations
Sourceimpl Debug for ThreadStartSchema
impl Debug for ThreadStartSchema
Sourceimpl JsonSchema for ThreadStartSchema
impl JsonSchema for ThreadStartSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ThreadStartSchema
impl RefUnwindSafe for ThreadStartSchema
impl Send for ThreadStartSchema
impl Sync for ThreadStartSchema
impl Unpin for ThreadStartSchema
impl UnsafeUnpin for ThreadStartSchema
impl UnwindSafe for ThreadStartSchema