pub struct TimelineActionSchema {Show 17 fields
pub output_kind: String,
pub status: String,
pub action: String,
pub thread: String,
pub branch_id: Option<String>,
pub parent_branch_id: Option<String>,
pub from_step_id: Option<String>,
pub cursor_branch_id: Option<String>,
pub cursor_step_id: Option<String>,
pub operation_id: Option<String>,
pub recovered_operation_id: Option<String>,
pub materialized: Option<bool>,
pub materialization_status: Option<String>,
pub recovery_status: Option<String>,
pub blocker_count: usize,
pub branch_count: usize,
pub step_count: usize,
}Fields
output_kind: Stringstatus: Stringaction: Stringthread: Stringbranch_id: Option<String>parent_branch_id: Option<String>from_step_id: Option<String>cursor_branch_id: Option<String>cursor_step_id: Option<String>operation_id: Option<String>recovered_operation_id: Option<String>materialized: Option<bool>materialization_status: Option<String>recovery_status: Option<String>blocker_count: usizebranch_count: usizestep_count: usizeTrait Implementations
Sourceimpl Debug for TimelineActionSchema
impl Debug for TimelineActionSchema
Sourceimpl JsonSchema for TimelineActionSchema
impl JsonSchema for TimelineActionSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineActionSchema
impl RefUnwindSafe for TimelineActionSchema
impl Send for TimelineActionSchema
impl Sync for TimelineActionSchema
impl Unpin for TimelineActionSchema
impl UnsafeUnpin for TimelineActionSchema
impl UnwindSafe for TimelineActionSchema