pub struct TimelineActionsSchema {
pub can_undo: bool,
pub can_redo: bool,
}Fields
can_undo: boolcan_redo: boolTrait Implementations
Sourceimpl Debug for TimelineActionsSchema
impl Debug for TimelineActionsSchema
Sourceimpl JsonSchema for TimelineActionsSchema
impl JsonSchema for TimelineActionsSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineActionsSchema
impl RefUnwindSafe for TimelineActionsSchema
impl Send for TimelineActionsSchema
impl Sync for TimelineActionsSchema
impl Unpin for TimelineActionsSchema
impl UnsafeUnpin for TimelineActionsSchema
impl UnwindSafe for TimelineActionsSchema