pub struct TimelineBranchSchema {
pub branch_id: String,
pub parent_branch_id: Option<String>,
pub forked_from_step_id: Option<String>,
pub forked_from_state: Option<String>,
pub reason: Option<String>,
pub created_at_ms: Option<i64>,
pub step_ids: Vec<String>,
pub is_active: bool,
pub is_on_active_path: bool,
}Fields
branch_id: Stringparent_branch_id: Option<String>forked_from_step_id: Option<String>forked_from_state: Option<String>reason: Option<String>created_at_ms: Option<i64>step_ids: Vec<String>is_active: boolis_on_active_path: boolTrait Implementations
Sourceimpl Debug for TimelineBranchSchema
impl Debug for TimelineBranchSchema
Sourceimpl JsonSchema for TimelineBranchSchema
impl JsonSchema for TimelineBranchSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineBranchSchema
impl RefUnwindSafe for TimelineBranchSchema
impl Send for TimelineBranchSchema
impl Sync for TimelineBranchSchema
impl Unpin for TimelineBranchSchema
impl UnsafeUnpin for TimelineBranchSchema
impl UnwindSafe for TimelineBranchSchema