pub struct TimelineCursorSchema {
pub branch_id: Option<String>,
pub step_id: Option<String>,
pub state: Option<String>,
pub state_full: Option<String>,
}Fields
branch_id: Option<String>step_id: Option<String>state: Option<String>state_full: Option<String>Trait Implementations
Sourceimpl Debug for TimelineCursorSchema
impl Debug for TimelineCursorSchema
Sourceimpl JsonSchema for TimelineCursorSchema
impl JsonSchema for TimelineCursorSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineCursorSchema
impl RefUnwindSafe for TimelineCursorSchema
impl Send for TimelineCursorSchema
impl Sync for TimelineCursorSchema
impl Unpin for TimelineCursorSchema
impl UnsafeUnpin for TimelineCursorSchema
impl UnwindSafe for TimelineCursorSchema