pub struct TimelineLogSchema {
pub output_kind: String,
pub status: String,
pub repository_capability: String,
pub storage_model: String,
pub thread: String,
pub cursor: TimelineCursorSchema,
pub branches: Vec<TimelineBranchSchema>,
pub steps: Vec<TimelineStepSchema>,
pub active_branch_path: Vec<String>,
pub actions: TimelineActionsSchema,
pub recovery: Option<TimelineRecoverySchema>,
}Fields
output_kind: Stringstatus: Stringrepository_capability: Stringstorage_model: Stringthread: Stringcursor: TimelineCursorSchemabranches: Vec<TimelineBranchSchema>steps: Vec<TimelineStepSchema>active_branch_path: Vec<String>actions: TimelineActionsSchemarecovery: Option<TimelineRecoverySchema>Trait Implementations
Sourceimpl Debug for TimelineLogSchema
impl Debug for TimelineLogSchema
Sourceimpl JsonSchema for TimelineLogSchema
impl JsonSchema for TimelineLogSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineLogSchema
impl RefUnwindSafe for TimelineLogSchema
impl Send for TimelineLogSchema
impl Sync for TimelineLogSchema
impl Unpin for TimelineLogSchema
impl UnsafeUnpin for TimelineLogSchema
impl UnwindSafe for TimelineLogSchema