pub struct TimelineNativeSchema {
pub harness: String,
pub session_id: Option<String>,
pub message_id: Option<String>,
pub tool_call_id: String,
}Fields
harness: Stringsession_id: Option<String>message_id: Option<String>tool_call_id: StringTrait Implementations
Sourceimpl Debug for TimelineNativeSchema
impl Debug for TimelineNativeSchema
Sourceimpl JsonSchema for TimelineNativeSchema
impl JsonSchema for TimelineNativeSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineNativeSchema
impl RefUnwindSafe for TimelineNativeSchema
impl Send for TimelineNativeSchema
impl Sync for TimelineNativeSchema
impl Unpin for TimelineNativeSchema
impl UnsafeUnpin for TimelineNativeSchema
impl UnwindSafe for TimelineNativeSchema