pub struct TimelineRecordingSchema {Show 16 fields
pub output_kind: String,
pub status: String,
pub action: String,
pub thread: String,
pub step_id: String,
pub branch_id: String,
pub parent_step_id: Option<String>,
pub operation_id: String,
pub before_state: Option<String>,
pub after_state: Option<String>,
pub changed: Option<bool>,
pub tool_status: Option<String>,
pub payload_summary: Option<String>,
pub payload_hash: Option<String>,
pub branch_count: usize,
pub step_count: usize,
}Fields
output_kind: Stringstatus: Stringaction: Stringthread: Stringstep_id: Stringbranch_id: Stringparent_step_id: Option<String>operation_id: Stringbefore_state: Option<String>after_state: Option<String>changed: Option<bool>tool_status: Option<String>payload_summary: Option<String>payload_hash: Option<String>branch_count: usizestep_count: usizeTrait Implementations
Sourceimpl Debug for TimelineRecordingSchema
impl Debug for TimelineRecordingSchema
Sourceimpl JsonSchema for TimelineRecordingSchema
impl JsonSchema for TimelineRecordingSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineRecordingSchema
impl RefUnwindSafe for TimelineRecordingSchema
impl Send for TimelineRecordingSchema
impl Sync for TimelineRecordingSchema
impl Unpin for TimelineRecordingSchema
impl UnsafeUnpin for TimelineRecordingSchema
impl UnwindSafe for TimelineRecordingSchema