pub struct TimelineRecoverySchema {
pub status: String,
pub branch_id: String,
pub from_step_id: Option<String>,
pub to_step_id: Option<String>,
pub from_state: String,
pub to_state: String,
pub reason: String,
pub moved_at_ms: i64,
pub checkout_state: Option<String>,
}Fields
status: Stringbranch_id: Stringfrom_step_id: Option<String>to_step_id: Option<String>from_state: Stringto_state: Stringreason: Stringmoved_at_ms: i64checkout_state: Option<String>Trait Implementations
Sourceimpl Debug for TimelineRecoverySchema
impl Debug for TimelineRecoverySchema
Sourceimpl JsonSchema for TimelineRecoverySchema
impl JsonSchema for TimelineRecoverySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineRecoverySchema
impl RefUnwindSafe for TimelineRecoverySchema
impl Send for TimelineRecoverySchema
impl Sync for TimelineRecoverySchema
impl Unpin for TimelineRecoverySchema
impl UnsafeUnpin for TimelineRecoverySchema
impl UnwindSafe for TimelineRecoverySchema