pub struct TimelineStatusRecoverySchema {
pub status: String,
pub branch_id: String,
pub from_step_id: Option<String>,
pub to_step_id: Option<String>,
pub from_state: String,
pub to_state: String,
pub reason: String,
pub moved_at_ms: i64,
pub checkout_state: Option<String>,
}Fields
status: Stringbranch_id: Stringfrom_step_id: Option<String>to_step_id: Option<String>from_state: Stringto_state: Stringreason: Stringmoved_at_ms: i64checkout_state: Option<String>Trait Implementations
Sourceimpl Debug for TimelineStatusRecoverySchema
impl Debug for TimelineStatusRecoverySchema
Sourceimpl JsonSchema for TimelineStatusRecoverySchema
impl JsonSchema for TimelineStatusRecoverySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineStatusRecoverySchema
impl RefUnwindSafe for TimelineStatusRecoverySchema
impl Send for TimelineStatusRecoverySchema
impl Sync for TimelineStatusRecoverySchema
impl Unpin for TimelineStatusRecoverySchema
impl UnsafeUnpin for TimelineStatusRecoverySchema
impl UnwindSafe for TimelineStatusRecoverySchema