pub struct TimelineStatusSchema {Show 13 fields
pub output_kind: String,
pub status: String,
pub thread: String,
pub cursor_branch_id: Option<String>,
pub cursor_step_id: Option<String>,
pub cursor_state: Option<String>,
pub current_step: Option<TimelineStatusStepSchema>,
pub active_branch_path: Vec<String>,
pub can_undo: bool,
pub can_redo: bool,
pub branch_count: usize,
pub step_count: usize,
pub recovery: Option<TimelineStatusRecoverySchema>,
}Fields
output_kind: Stringstatus: Stringthread: Stringcursor_branch_id: Option<String>cursor_step_id: Option<String>cursor_state: Option<String>current_step: Option<TimelineStatusStepSchema>active_branch_path: Vec<String>can_undo: boolcan_redo: boolbranch_count: usizestep_count: usizerecovery: Option<TimelineStatusRecoverySchema>Trait Implementations
Sourceimpl Debug for TimelineStatusSchema
impl Debug for TimelineStatusSchema
Sourceimpl JsonSchema for TimelineStatusSchema
impl JsonSchema for TimelineStatusSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineStatusSchema
impl RefUnwindSafe for TimelineStatusSchema
impl Send for TimelineStatusSchema
impl Sync for TimelineStatusSchema
impl Unpin for TimelineStatusSchema
impl UnsafeUnpin for TimelineStatusSchema
impl UnwindSafe for TimelineStatusSchema