pub struct TimelineStatusStepSchema {Show 16 fields
pub step_id: String,
pub branch_id: String,
pub parent_step_id: Option<String>,
pub tool_name: Option<String>,
pub tool_status: Option<String>,
pub changed: Option<bool>,
pub payload_summary: Option<String>,
pub payload_hash: Option<String>,
pub labels: Vec<String>,
pub started_at_ms: Option<i64>,
pub finished_at_ms: Option<i64>,
pub can_seek: bool,
pub can_fork: bool,
pub can_reset: bool,
pub can_materialize: bool,
pub has_boundary_warning: bool,
}Fields
step_id: Stringbranch_id: Stringparent_step_id: Option<String>tool_name: Option<String>tool_status: Option<String>changed: Option<bool>payload_summary: Option<String>payload_hash: Option<String>labels: Vec<String>started_at_ms: Option<i64>finished_at_ms: Option<i64>can_seek: boolcan_fork: boolcan_reset: boolcan_materialize: boolhas_boundary_warning: boolTrait Implementations
Sourceimpl Debug for TimelineStatusStepSchema
impl Debug for TimelineStatusStepSchema
Sourceimpl JsonSchema for TimelineStatusStepSchema
impl JsonSchema for TimelineStatusStepSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineStatusStepSchema
impl RefUnwindSafe for TimelineStatusStepSchema
impl Send for TimelineStatusStepSchema
impl Sync for TimelineStatusStepSchema
impl Unpin for TimelineStatusStepSchema
impl UnsafeUnpin for TimelineStatusStepSchema
impl UnwindSafe for TimelineStatusStepSchema