pub struct TimelineStepSchema {Show 27 fields
pub step_id: String,
pub branch_id: String,
pub parent_step_id: Option<String>,
pub native: Option<TimelineNativeSchema>,
pub tool_name: Option<String>,
pub status: Option<String>,
pub changed: Option<bool>,
pub touched_paths: Vec<String>,
pub labels: Vec<String>,
pub before_state: Option<String>,
pub after_state: Option<String>,
pub capture_state: Option<String>,
pub cursor_state: Option<String>,
pub cursor_state_full: Option<String>,
pub payload_summary: Option<String>,
pub payload_hash: Option<String>,
pub capture_oplog_batch_id: Option<u64>,
pub started_at_ms: Option<i64>,
pub finished_at_ms: Option<i64>,
pub operation_ids: Vec<String>,
pub is_current: bool,
pub is_on_active_branch_path: bool,
pub can_seek: bool,
pub can_fork: bool,
pub can_reset: bool,
pub can_materialize: bool,
pub has_boundary_warning: bool,
}Fields
step_id: Stringbranch_id: Stringparent_step_id: Option<String>native: Option<TimelineNativeSchema>tool_name: Option<String>status: Option<String>changed: Option<bool>touched_paths: Vec<String>labels: Vec<String>before_state: Option<String>after_state: Option<String>capture_state: Option<String>cursor_state: Option<String>cursor_state_full: Option<String>payload_summary: Option<String>payload_hash: Option<String>capture_oplog_batch_id: Option<u64>started_at_ms: Option<i64>finished_at_ms: Option<i64>operation_ids: Vec<String>is_current: boolis_on_active_branch_path: boolcan_seek: boolcan_fork: boolcan_reset: boolcan_materialize: boolhas_boundary_warning: boolTrait Implementations
Sourceimpl Debug for TimelineStepSchema
impl Debug for TimelineStepSchema
Sourceimpl JsonSchema for TimelineStepSchema
impl JsonSchema for TimelineStepSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TimelineStepSchema
impl RefUnwindSafe for TimelineStepSchema
impl Send for TimelineStepSchema
impl Sync for TimelineStepSchema
impl Unpin for TimelineStepSchema
impl UnsafeUnpin for TimelineStepSchema
impl UnwindSafe for TimelineStepSchema