pub struct TrySchema {Show 16 fields
pub status: String,
pub action: String,
pub message: String,
pub thread: String,
pub thread_dropped: bool,
pub cleanup_error: Option<String>,
pub exit_code: Option<i32>,
pub duration_ms: u128,
pub captured_state: Option<String>,
pub merge_state: Option<String>,
pub next_action: Option<String>,
pub next_action_template: Option<ActionTemplateSchema>,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub recovery_commands: Vec<String>,
pub recovery_action_templates: Vec<ActionTemplateSchema>,
}Fields
status: Stringaction: Stringmessage: Stringthread: Stringthread_dropped: boolcleanup_error: Option<String>exit_code: Option<i32>duration_ms: u128captured_state: Option<String>merge_state: Option<String>next_action: Option<String>next_action_template: Option<ActionTemplateSchema>recommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>recovery_commands: Vec<String>recovery_action_templates: Vec<ActionTemplateSchema>Trait Implementations
Sourceimpl JsonSchema for TrySchema
impl JsonSchema for TrySchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TrySchema
impl RefUnwindSafe for TrySchema
impl Send for TrySchema
impl Sync for TrySchema
impl Unpin for TrySchema
impl UnsafeUnpin for TrySchema
impl UnwindSafe for TrySchema