pub struct VerificationCheckSchema {
pub name: String,
pub status: String,
pub clean: bool,
pub summary: String,
pub recommended_action: Option<String>,
pub recommended_action_template: Option<ActionTemplateSchema>,
pub recovery_commands: Vec<String>,
pub recovery_action_templates: Vec<ActionTemplateSchema>,
pub details: BTreeMap<String, String>,
}Fields
name: Stringstatus: Stringclean: boolsummary: Stringrecommended_action: Option<String>recommended_action_template: Option<ActionTemplateSchema>recovery_commands: Vec<String>recovery_action_templates: Vec<ActionTemplateSchema>details: BTreeMap<String, String>Trait Implementations
Sourceimpl Debug for VerificationCheckSchema
impl Debug for VerificationCheckSchema
Sourceimpl JsonSchema for VerificationCheckSchema
impl JsonSchema for VerificationCheckSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for VerificationCheckSchema
impl RefUnwindSafe for VerificationCheckSchema
impl Send for VerificationCheckSchema
impl Sync for VerificationCheckSchema
impl Unpin for VerificationCheckSchema
impl UnsafeUnpin for VerificationCheckSchema
impl UnwindSafe for VerificationCheckSchema