pub struct WatchLineSchema {
pub ts: String,
pub thread: Option<String>,
pub kind: String,
pub state_id: Option<String>,
pub intent: Option<String>,
pub confidence: Option<f32>,
pub actor: Option<ActorInfoSchema>,
pub id: u64,
}Fields
ts: Stringthread: Option<String>kind: Stringstate_id: Option<String>intent: Option<String>confidence: Option<f32>actor: Option<ActorInfoSchema>id: u64Trait Implementations
Sourceimpl Debug for WatchLineSchema
impl Debug for WatchLineSchema
Sourceimpl JsonSchema for WatchLineSchema
impl JsonSchema for WatchLineSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WatchLineSchema
impl RefUnwindSafe for WatchLineSchema
impl Send for WatchLineSchema
impl Sync for WatchLineSchema
impl Unpin for WatchLineSchema
impl UnsafeUnpin for WatchLineSchema
impl UnwindSafe for WatchLineSchema