pub struct WorktreeIndexInspectionSchema {
pub present: bool,
pub file_entries: usize,
pub directory_entries: usize,
pub untracked_directory_entries: usize,
pub snapshot_bytes: u64,
pub journal_bytes: u64,
pub journal_ops: usize,
pub journal_replay_ms: u128,
pub error: Option<String>,
}Fields
present: boolfile_entries: usizedirectory_entries: usizeuntracked_directory_entries: usizesnapshot_bytes: u64journal_bytes: u64journal_ops: usizejournal_replay_ms: u128error: Option<String>Trait Implementations
Sourceimpl JsonSchema for WorktreeIndexInspectionSchema
impl JsonSchema for WorktreeIndexInspectionSchema
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for WorktreeIndexInspectionSchema
impl RefUnwindSafe for WorktreeIndexInspectionSchema
impl Send for WorktreeIndexInspectionSchema
impl Sync for WorktreeIndexInspectionSchema
impl Unpin for WorktreeIndexInspectionSchema
impl UnsafeUnpin for WorktreeIndexInspectionSchema
impl UnwindSafe for WorktreeIndexInspectionSchema